@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005 - 2011 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2005-2011 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTAPPOINTMENT_H
@@ -67,7 +54,7 @@ class PLANKERNEL_EXPORT AppointmentInterval
 {
 public:
     AppointmentInterval();
-    AppointmentInterval(const AppointmentInterval &AppointmentInterval);
+    AppointmentInterval(const AppointmentInterval &other);
     AppointmentInterval(const DateTime &start, const DateTime &end, double load=100);
     AppointmentInterval(QDate date, const TimeInterval &timeInterval, double load=100);
     ~AppointmentInterval();
@@ -85,13 +72,22 @@ public:
     void setEndTime(const DateTime &time);
     double load() const;
     void setLoad(double load);
-    
+    QTimeZone timeZone() const;
+    AppointmentInterval &toTimeZone(const QTimeZone &tz);
+
     bool isValid() const;
+
     AppointmentInterval firstInterval(const AppointmentInterval &interval, const DateTime &from) const;
 
+    /// Merge this interval with @p interval if it is conticuous to this.
+    /// @return true if merged
+    bool merge(const AppointmentInterval &interval);
+    AppointmentInterval &operator=(const AppointmentInterval &interval);
     bool operator==(const AppointmentInterval &interval) const;
+    bool operator!=(const AppointmentInterval &interval) const;
     bool operator<(const AppointmentInterval &interval) const;
 
+    bool isConticuousTo(const AppointmentInterval &other) const;
     bool intersects(const AppointmentInterval &other) const;
     AppointmentInterval interval(const DateTime &start, const DateTime &end) const;
 
@@ -112,8 +108,14 @@ class PLANKERNEL_EXPORT AppointmentIntervalList
 {
 public:
     AppointmentIntervalList();
+    AppointmentIntervalList(const AppointmentIntervalList &lst);
+
     AppointmentIntervalList(const QMultiMap<QDate, AppointmentInterval> &other);
 
+    QTimeZone timeZone() const;
+    /// Convert intervals to timezone @p tz
+    AppointmentIntervalList &toTimeZone(const QTimeZone &tz);
+
     /// Add @p interval to the list. Handle overlapping with existing intervals.
     void add(const AppointmentInterval &interval);
     /// Add an interval to the list. Handle overlapping with existing intervals.
@@ -129,7 +131,7 @@ public:
 
     /// Returns the intervals in the range @p start, @p end
     AppointmentIntervalList extractIntervals(const DateTime &start, const DateTime &end) const;
-    
+
     /// Return the total effort
     Duration effort() const;
     /// Return the effort limited to the interval @p start, @p end
@@ -168,6 +170,9 @@ public:
     Appointment(const Appointment &app);
     ~Appointment();
 
+    /// Convert appointment to timezone @p tz
+    Appointment &toTimeZone(const QTimeZone &tz);
+
     bool isEmpty() const { return m_intervals.isEmpty(); }
     void clear();
 
@@ -206,7 +211,7 @@ public:
     /// Return intervals between @p start and @p end
     AppointmentIntervalList intervals(const DateTime &start, const DateTime &end) const;
 
-    bool loadXML(KoXmlElement &element, XMLLoaderObject &status, Schedule &sch);
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     void saveXML(QDomElement &element) const;
 
     /**
@@ -278,4 +283,7 @@ private:
 
 }  //KPlato namespace
 
+PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::Appointment *a);
+PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::Appointment &a);
+
 #endif
