@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Thomas zander <zander@kde.org>
-   Copyright (C) 2002 - 2010, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2001 Thomas zander <zander@kde.org>
+   SPDX-FileCopyrightText: 2002-2010, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "kptnode.h"
@@ -40,9 +27,9 @@ namespace KPlato
 {
 
 Node::Node(Node *parent) 
-    : QObject(0), // We don't use qobjects parent
+    : QObject(nullptr), // We don't use qobjects parent
       m_nodes(), m_dependChildNodes(), m_dependParentNodes(),
-      m_estimate(0),
+      m_estimate(nullptr),
       m_blockChanged(false)
 {
     //debugPlan<<"("<<this<<")";
@@ -52,11 +39,11 @@ Node::Node(Node *parent)
 }
 
 Node::Node(const Node &node, Node *parent) 
-    : QObject(0), // Don't set parent, we handle parent/child ourselves
+    : QObject(nullptr), // Don't set parent, we handle parent/child ourselves
       m_nodes(), 
       m_dependChildNodes(), 
       m_dependParentNodes(),
-      m_estimate(0),
+      m_estimate(nullptr),
       m_blockChanged(false)
 {
     //debugPlan<<"("<<this<<")";
@@ -84,10 +71,7 @@ Node::~Node() {
     delete m_estimate;
     while (!m_nodes.isEmpty())
         delete m_nodes.takeFirst();
-    
-    if (findNode() == this) {
-        removeId(); // only remove myself (I may be just a working copy)
-    }
+
     while (!m_dependParentNodes.isEmpty()) {
         delete m_dependParentNodes.value(0);
     }
@@ -101,26 +85,25 @@ Node::~Node() {
     if (m_shutdownAccount)
         m_shutdownAccount->removeShutdown(*this);
 
-    foreach (Schedule *s, m_schedules) {
+    for (Schedule *s : std::as_const(m_schedules)) {
         delete s;
     }
     m_schedules.clear();
-    m_parent = 0; //safety
+    m_parent = nullptr; //safety
 }
 
 void Node::init() {
     m_priority = 0;
     m_documents.node = this;
-    m_currentSchedule = 0;
-    m_name="";
+    m_currentSchedule = nullptr;
     m_constraint = Node::ASAP;
-    m_estimate = 0;
+    m_estimate = nullptr;
     m_visitedForward = false;
     m_visitedBackward = false;
     
-    m_runningAccount = 0;
-    m_startupAccount = 0;
-    m_shutdownAccount = 0;
+    m_runningAccount = nullptr;
+    m_startupAccount = nullptr;
+    m_shutdownAccount = nullptr;
     m_startupCost = 0.0;
     m_shutdownCost = 0.0;
 }
@@ -136,6 +119,11 @@ int Node::priority() const
     return m_priority;
 }
 
+ulong Node::granularity() const
+{
+    return parentNode() ? parentNode()->granularity() : 0;
+}
+
 QString Node::typeToString(bool trans) const
 {
     return typeToString((Node::NodeTypes)type(), trans);
@@ -151,13 +139,13 @@ QString Node::typeToString(Node::NodeTypes typ, bool trans)
 QStringList Node::typeToStringList(bool trans)
 {
     return QStringList() 
-            << (trans ? i18n("None") : QString("None"))
-            << (trans ? i18n("Project") : QString("Project"))
-            << (trans ? i18n("Sub-Project") : QString("Sub-Project"))
-            << (trans ? i18n("Task") : QString("Task"))
-            << (trans ? i18n("Milestone") : QString("Milestone"))
-            << (trans ? i18n("Periodic") : QString("Periodic"))
-            << (trans ? i18n("Summary") : QString("Summary-Task"));
+            << (trans ? i18n("None") : QStringLiteral("None"))
+            << (trans ? i18n("Project") : QStringLiteral("Project"))
+            << (trans ? i18n("Sub-Project") : QStringLiteral("Sub-Project"))
+            << (trans ? i18n("Task") : QStringLiteral("Task"))
+            << (trans ? i18n("Milestone") : QStringLiteral("Milestone"))
+            << (trans ? i18n("Periodic") : QStringLiteral("Periodic"))
+            << (trans ? i18n("Summary") : QStringLiteral("Summary-Task"));
 }
 
 void Node::setName(const QString &n) 
@@ -189,7 +177,7 @@ Node *Node::projectNode() {
         return m_parent->projectNode();
 
     // This happens for default tasks
-    return 0;
+    return nullptr;
 }
 
 const Node *Node::projectNode() const {
@@ -200,7 +188,7 @@ const Node *Node::projectNode() const {
         return m_parent->projectNode();
 
     // This happens for default tasks
-    return 0;
+    return nullptr;
 }
 
 void Node::takeChildNode(Node *node) {
@@ -210,7 +198,7 @@ void Node::takeChildNode(Node *node) {
     if (i != -1) {
         m_nodes.removeAt(i);
     }
-    node->setParentNode(0);
+    node->setParentNode(nullptr);
     if (t != type()) {
         changed(TypeProperty);
     }
@@ -222,7 +210,7 @@ void Node::takeChildNode(int number) {
         Node *n = m_nodes.takeAt(number);
         //debugPlan<<(n?n->id():"null")<<" :"<<(n?n->name():"");
         if (n) {
-            n->setParentNode(0);
+            n->setParentNode(nullptr);
         }
     }
     if (t != type()) {
@@ -267,7 +255,7 @@ int Node::findChildNode(const Node* node) const
 
 bool Node::isChildOf(const Node* node) const
 {
-    if (node == 0 || m_parent == 0) {
+    if (node == nullptr || m_parent == nullptr) {
         return false;
     }
     if (node == m_parent) {
@@ -286,7 +274,7 @@ Node* Node::childNode(int number)
 const Node* Node::childNode(int number) const
 {
     if (number < 0 || number >= m_nodes.count()) {
-        return 0;
+        return nullptr;
     }
     return m_nodes.at(number);
 }
@@ -301,7 +289,7 @@ Duration *Node::getDelay() {
     /* TODO
        Calculate the delay of this node. Use the calculated startTime and the set startTime.
     */
-    return 0L;
+    return nullptr;
 }
 
 void Node::addDependChildNode(Node *node, Relation::Type p) {
@@ -394,7 +382,7 @@ Relation *Node::findParentRelation(const Node *node) const
         if (rel->parent() == node)
             return rel;
     }
-    return (Relation *)0;
+    return (Relation *)nullptr;
 }
 
 Relation *Node::findChildRelation(const Node *node) const
@@ -404,7 +392,7 @@ Relation *Node::findChildRelation(const Node *node) const
         if (rel->child() == node)
             return rel;
     }
-    return (Relation *)0;
+    return (Relation *)nullptr;
 }
 
 Relation *Node::findRelation(const Node *node) const
@@ -417,21 +405,81 @@ Relation *Node::findRelation(const Node *node) const
 
 bool Node::isDependChildOf(const Node *node) const
 {
-    //debugPlan<<" '"<<m_name<<"' checking against '"<<node->name()<<"'";
-    for (int i=0; i<numDependParentNodes(); i++) {
-        Relation *rel = getDependParentNode(i);
-        if (rel->parent() == node)
-            return true;
-        if (rel->parent()->isDependChildOf(node))
-            return true;
+    return isSuccessorof(node, false, true);
+}
+
+bool Node::isSuccessorof(const Node *node, bool checkProxies, bool checkSummarytasks) const
+{
+    //debugPlan<<this<<"checking against"<<node;
+    if (!checkSummarytasks && (type() == Type_Summarytask || node->type() == Type_Summarytask)) {
+        //debugPlan<<this<<type()<<"skip check"<<node<<node->type();
+        return false;
     }
+    //debugPlan<<this<<type()<<"checking against"<<node<<node->type();
+    for (const auto r : std::as_const(m_dependParentNodes)) {
+        if (r->parent() == node) {
+            //debugPlan<<"deps"<<r<<true;
+            return true;
+        }
+        if (r->parent()->isSuccessorof(node, checkProxies, checkSummarytasks)) {
+            //debugPlan<<"deps"<<true;
+            return true;
+        }
+    }
+    if (checkProxies) {
+        for (const auto r : std::as_const(m_parentProxyRelations)) {
+            if (r->parent() == node) {
+                //debugPlan<<"proxy"<<true<<r;
+                return true;
+            }
+            if (r->parent()->isSuccessorof(node, checkProxies, checkSummarytasks)) {
+                //debugPlan<<"proxy"<<true;
+                return true;
+            }
+        }
+    }
+    //debugPlan<<this<<"->"<<node<<false<<m_dependParentNodes<<"proxy"<<m_parentProxyRelations;;
+    return false;
+}
+
+bool Node::isPredecessorof(const Node *node, bool checkProxies, bool checkSummarytasks) const
+{
+    if (!checkSummarytasks && (type() == Type_Summarytask || node->type() == Type_Summarytask)) {
+        //debugPlan<<this<<type()<<"skip check"<<node<<node->type();
+        return false;
+    }
+    //debugPlan<<this<<type()<<"checking against"<<node<<node->type();
+    for (const auto r : m_dependChildNodes) {
+        if (r->child() == node) {
+            //debugPlan<<"deps"<<true<<r;
+            return true;
+        }
+        if (r->child()->isPredecessorof(node, checkProxies, checkSummarytasks)) {
+            //debugPlan<<"deps"<<true;
+            return true;
+        }
+    }
+    if (checkProxies) {
+        for (const auto r : std::as_const(m_childProxyRelations)) {
+            if (r->child() == node) {
+                //debugPlan<<"proxy"<<true<<r;
+                return true;
+            }
+            if (r->child()->isPredecessorof(node, checkProxies, checkSummarytasks)) {
+                //debugPlan<<"proxy"<<true;
+                return true;
+            }
+        }
+    }
+    //debugPlan<<this<<"->"<<node<<false<<"dep:"<<m_dependChildNodes<<"proxy"<<m_childProxyRelations;
     return false;
 }
 
 QList<Node*> Node::getParentNodes()
 {
     this->m_parentNodes.clear();
-    foreach(Relation * currentRelation, this->dependParentNodes())
+    const QList<Relation*> relations = this->dependParentNodes();
+    for (Relation * currentRelation : relations)
     {
         if (!this->m_parentNodes.contains(currentRelation->parent())) 
         {
@@ -453,7 +501,7 @@ bool Node::canMoveTo(const Node *newParent) const
         debugPlan<<"Can't move, node is dependent on new parent";
         return false;
     }
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         if (!n->canMoveTo(newParent)) {
             return false;
         }
@@ -617,7 +665,7 @@ QStringList Node::schedulingStatus(long id, bool trans) const
         lst = s->state();
     }
     if (lst.isEmpty()) {
-        lst.append(trans ? i18n("Not scheduled") : QString("Not scheduled"));
+        lst.append(trans ? i18n("Not scheduled") : QStringLiteral("Not scheduled"));
     }
     return lst;
 }
@@ -656,7 +704,7 @@ bool Node::notScheduled(long id) const
 {
     if (type() == Type_Summarytask) {
         // i am scheduled if al least on child is scheduled
-        foreach (Node *n, m_nodes) {
+        for (Node *n : std::as_const(m_nodes)) {
             if (! n->notScheduled(id)) {
                 return false;
             }
@@ -664,7 +712,7 @@ bool Node::notScheduled(long id) const
         return true;
     }
     Schedule *s = schedule(id);
-    return s == 0 || s->isDeleted() || s->notScheduled;
+    return s == nullptr || s->isDeleted() || s->notScheduled;
 }
 
 QStringList Node::overbookedResources(long id) const
@@ -683,7 +731,7 @@ void Node::saveRelations(QDomElement &element, const XmlSaveContext &context) co
     QListIterator<Relation*> it(m_dependChildNodes);
     while (it.hasNext()) {
         Relation *r = it.next();
-        if (context.saveNode(r->child())) {
+        if (context.saveRelation(r)) {
             r->save(element, context);
         }
     }
@@ -701,19 +749,19 @@ void Node::setConstraint(Node::ConstraintType type)
 
 void Node::setConstraint(const QString &type) {
     // Do not i18n these, they are used in load()
-    if (type == "ASAP")
+    if (type == QStringLiteral("ASAP"))
         setConstraint(ASAP);
-    else if (type == "ALAP")
+    else if (type == QStringLiteral("ALAP"))
         setConstraint(ALAP);
-    else if (type == "MustStartOn")
+    else if (type == QStringLiteral("MustStartOn"))
         setConstraint(MustStartOn);
-    else if (type == "MustFinishOn")
+    else if (type == QStringLiteral("MustFinishOn"))
         setConstraint(MustFinishOn);
-    else if (type == "StartNotEarlier")
+    else if (type == QStringLiteral("StartNotEarlier"))
         setConstraint(StartNotEarlier);
-    else if (type == "FinishNotLater")
+    else if (type == QStringLiteral("FinishNotLater"))
         setConstraint(FinishNotLater);
-    else if (type == "FixedInterval")
+    else if (type == QStringLiteral("FixedInterval"))
         setConstraint(FixedInterval);
     else
         setConstraint(ASAP);  // default
@@ -724,19 +772,19 @@ QString Node::constraintToString(bool trans) const {
 }
 
 QStringList Node::constraintList(bool trans) {
-    // keep theses in the same order as the enum!
+    // keep these in the same order as the enum!
     return QStringList() 
-            << (trans ? i18n("As Soon As Possible") : QString("ASAP"))
-            << (trans ? i18n("As Late As Possible") : QString("ALAP"))
-            << (trans ? i18n("Must Start On") : QString("MustStartOn"))
-            << (trans ? i18n("Must Finish On") : QString("MustFinishOn"))
-            << (trans ? i18n("Start Not Earlier") : QString("StartNotEarlier"))
-            << (trans ? i18n("Finish Not Later") : QString("FinishNotLater"))
-            << (trans ? i18n("Fixed Interval") : QString("FixedInterval"));
+            << (trans ? i18n("As Soon As Possible") : QStringLiteral("ASAP"))
+            << (trans ? i18n("As Late As Possible") : QStringLiteral("ALAP"))
+            << (trans ? i18n("Must Start On") : QStringLiteral("MustStartOn"))
+            << (trans ? i18n("Must Finish On") : QStringLiteral("MustFinishOn"))
+            << (trans ? i18n("Start Not Earlier") : QStringLiteral("StartNotEarlier"))
+            << (trans ? i18n("Finish Not Later") : QStringLiteral("FinishNotLater"))
+            << (trans ? i18n("Fixed Interval") : QStringLiteral("FixedInterval"));
 }
 
 void Node::propagateEarliestStart(DateTime &time) {
-    if (m_currentSchedule == 0) {
+    if (m_currentSchedule == nullptr) {
         return;
     }
     if (type() != Type_Project) {
@@ -749,18 +797,18 @@ void Node::propagateEarliestStart(DateTime &time) {
             case FinishNotLater:
             case MustFinishOn:
                 if (m_constraintEndTime < time) {
-                    m_currentSchedule->logWarning("Task constraint outside project constraint");
+                    m_currentSchedule->logWarning(i18n("Task constraint outside project constraint"));
 #ifndef PLAN_NLOGDEBUG
-                    m_currentSchedule->logDebug(QString("%1: end constraint %2 < %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
+                    m_currentSchedule->logDebug(QStringLiteral("%1: end constraint %2 < %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
 #endif
                 }
                 break;
             case MustStartOn:
             case FixedInterval:
                 if (m_constraintStartTime < time) {
-                    m_currentSchedule->logWarning("Task constraint outside project constraint");
+                    m_currentSchedule->logWarning(i18n("Task constraint outside project constraint"));
 #ifndef PLAN_NLOGDEBUG
-                    m_currentSchedule->logDebug(QString("%1: start constraint %2 < %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
+                    m_currentSchedule->logDebug(QStringLiteral("%1: start constraint %2 < %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
 #endif
                 }
                 break;
@@ -776,7 +824,7 @@ void Node::propagateEarliestStart(DateTime &time) {
 }
 
 void Node::propagateLatestFinish(DateTime &time) {
-    if (m_currentSchedule == 0) {
+    if (m_currentSchedule == nullptr) {
         return;
     }
     if (type() != Type_Project) {
@@ -788,18 +836,18 @@ void Node::propagateLatestFinish(DateTime &time) {
             case StartNotEarlier:
             case MustStartOn:
                 if (m_constraintStartTime > time) {
-                    m_currentSchedule->logWarning("Task constraint outside project constraint");
+                    m_currentSchedule->logWarning(i18n("Task constraint outside project constraint"));
 #ifndef PLAN_NLOGDEBUG
-                    m_currentSchedule->logDebug(QString("%1: start constraint %2 < %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
+                    m_currentSchedule->logDebug(QStringLiteral("%1: start constraint %2 < %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
 #endif
                 }
                 break;
             case MustFinishOn:
             case FixedInterval:
                 if (m_constraintEndTime > time) {
-                    m_currentSchedule->logWarning("Task constraint outside project constraint");
+                    m_currentSchedule->logWarning(i18n("Task constraint outside project constraint"));
 #ifndef PLAN_NLOGDEBUG
-                    m_currentSchedule->logDebug(QString("%1: end constraint %2 > %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
+                    m_currentSchedule->logDebug(QStringLiteral("%1: end constraint %2 > %3").arg(constraintToString(true), m_constraintEndTime.toString(), time.toString()));
 #endif
                 }
                 break;
@@ -815,7 +863,7 @@ void Node::propagateLatestFinish(DateTime &time) {
 }
 
 void Node::moveEarliestStart(DateTime &time) {
-    if (m_currentSchedule == 0)
+    if (m_currentSchedule == nullptr)
         return;
     if (m_currentSchedule->earlyStart < time) {
         //m_currentSchedule->logDebug("moveEarliestStart: " + m_currentSchedule->earlyStart.toString() + " -> " + time.toString());
@@ -828,7 +876,7 @@ void Node::moveEarliestStart(DateTime &time) {
 }
 
 void Node::moveLatestFinish(DateTime &time) {
-    if (m_currentSchedule == 0)
+    if (m_currentSchedule == nullptr)
         return;
     if (m_currentSchedule->lateFinish > time)
         m_currentSchedule->lateFinish = time;
@@ -846,7 +894,6 @@ void Node::initiateCalculation(MainSchedule &sch) {
     m_earlyStart = DateTime();
     m_earlyFinish = DateTime();
     m_lateFinish = DateTime();
-
     QListIterator<Node*> it = m_nodes;
     while (it.hasNext()) {
         it.next()->initiateCalculation(sch);
@@ -866,7 +913,7 @@ Node *Node::siblingBefore() {
     //debugPlan;
     if (parentNode())
         return parentNode()->childBefore(this);
-    return 0;
+    return nullptr;
 }
 
 Node *Node::childBefore(Node *node) {
@@ -875,14 +922,14 @@ Node *Node::childBefore(Node *node) {
     if (index > 0){
         return m_nodes.at(index-1);
     }
-    return 0;
+    return nullptr;
 }
 
 Node *Node::siblingAfter() {
     //debugPlan;
     if (parentNode())
         return parentNode()->childAfter(this);
-    return 0;
+    return nullptr;
 }
 
 Node *Node::childAfter(Node *node)
@@ -893,7 +940,7 @@ Node *Node::childAfter(Node *node)
     if (index < m_nodes.count()-1) {
         return m_nodes.at(index+1);
     }
-    return 0;
+    return nullptr;
 }
 
 bool Node::moveChildUp(Node* node)
@@ -980,7 +1027,8 @@ QList<Resource*> Node::assignedResources(long id) const {
     Schedule *s = schedule(id);
     QList<Resource*> res;
     if (s) {
-        foreach (Appointment *a, s->appointments()) {
+        const QList<Appointment*> appointments = s->appointments();
+        for (Appointment *a : appointments) {
             res << a->resource()->resource();
         }
     }
@@ -1002,7 +1050,7 @@ QList<Resource*> Node::assignedResources(long id) const {
 // called from resource side when resource adds appointment
 bool Node::addAppointment(Appointment *appointment, Schedule &main) {
     Schedule *s = findSchedule(main.id());
-    if (s == 0) {
+    if (s == nullptr) {
         s = createSchedule(&main);
     }
     appointment->setNode(s);
@@ -1012,7 +1060,7 @@ bool Node::addAppointment(Appointment *appointment, Schedule &main) {
 
 void Node::addAppointment(ResourceSchedule *resource, const DateTime &start, const DateTime &end, double load) {
     Schedule *node = findSchedule(resource->id());
-    if (node == 0) {
+    if (node == nullptr) {
         node = createSchedule(resource->parent());
     }
     node->setCalculationMode(resource->calculationMode());
@@ -1026,15 +1074,15 @@ bool Node::isBaselined(long id) const
 }
 
 void Node::takeSchedule(const Schedule *schedule) {
-    if (schedule == 0)
+    if (schedule == nullptr)
         return;
     if (m_currentSchedule == schedule)
-        m_currentSchedule = 0;
+        m_currentSchedule = nullptr;
     m_schedules.take(schedule->id());
 }
 
 void Node::addSchedule(Schedule *schedule) {
-    if (schedule == 0)
+    if (schedule == nullptr)
         return;
     m_schedules.insert(schedule->id(), schedule);
 }
@@ -1057,24 +1105,24 @@ Schedule *Node::schedule(long id) const
 {
     switch (id) {
         case ANYSCHEDULED: {
-            foreach (Schedule *s, m_schedules) {
+            for (Schedule *s : std::as_const(m_schedules)) {
                 if (s->isScheduled()) {
                     return s;
                 }
             }
-            return 0;
+            return nullptr;
         }
         case CURRENTSCHEDULE:
             return m_currentSchedule;
         case NOTSCHEDULED:
-            return 0;
+            return nullptr;
         case BASELINESCHEDULE: {
-            foreach (Schedule *s, m_schedules) {
+            for (Schedule *s : std::as_const(m_schedules)) {
                 if (s->isBaselined()) {
                     return s;
                 }
             }
-            return 0;
+            return nullptr;
         }
         default:
             break;
@@ -1088,38 +1136,37 @@ Schedule *Node::findSchedule(long id) const
 }
 
 Schedule *Node::findSchedule(const QString &name, const Schedule::Type type) {
-    QHash<long, Schedule*> it;
-    foreach (Schedule *sch, it) {
+    const QHash<long, Schedule*> it;
+    for (Schedule *sch : it) {
         if (!sch->isDeleted() && 
             sch->name() == name && sch->type() == type)
             return sch;
     }
-    return 0;
+    return nullptr;
 }
 
 Schedule *Node::findSchedule(const QString &name) {
-    foreach (Schedule *sch, m_schedules) {
+    for (Schedule *sch : std::as_const(m_schedules)) {
         if (!sch->isDeleted() && sch->name() == name)
             return sch;
     }
-    return 0;
+    return nullptr;
 }
 
 
 Schedule *Node::findSchedule(const Schedule::Type type) {
     //debugPlan<<m_name<<" find type="<<type<<" nr="<<m_schedules.count();
-    QHash<long, Schedule*> hash;
-    foreach (Schedule *sch, hash) {
+    for (Schedule *sch : std::as_const(m_schedules)) {
         if (!sch->isDeleted() && sch->type() == type) {
             return sch;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void Node::setScheduleDeleted(long id, bool on) {
     Schedule *ns = findSchedule(id);
-    if (ns == 0) {
+    if (ns == nullptr) {
         errorPlan<<m_name<<" Could not find schedule with id="<<id;
     } else {
         ns->setDeleted(on);
@@ -1138,7 +1185,7 @@ void Node::setParentSchedule(Schedule *sch) {
 }
 
 bool Node::calcCriticalPath(bool fromEnd) {
-    if (m_currentSchedule == 0)
+    if (m_currentSchedule == nullptr)
         return false;
     //debugPlan<<m_name;
     if (!isCritical()) {
@@ -1162,7 +1209,7 @@ bool Node::calcCriticalPath(bool fromEnd) {
 }
 
 void Node::calcFreeFloat() {
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         n->calcFreeFloat();
     }
     return;
@@ -1175,7 +1222,7 @@ int Node::level() const {
 
 QString Node::generateWBSCode(QList<int> &indexes, bool sortable) const {
     //debugPlan<<m_name<<indexes;
-    if (m_parent == 0) {
+    if (m_parent == nullptr) {
         return QString();
     }
     indexes.insert(0, m_parent->indexOf(this));
@@ -1191,7 +1238,7 @@ QString Node::wbsCode(bool sortable) const {
 bool Node::isScheduled(long id) const
 {
     Schedule *s = schedule(id);
-    return s != 0 && s->isScheduled();
+    return s != nullptr && s->isScheduled();
 }
 
 void Node::setCurrentSchedule(long id) {
@@ -1266,7 +1313,7 @@ void Node::changed(Node *node, int property) {
         case CompletionRemainingEffortProperty:
         case CompletionActualEffortProperty:
         case CompletionUsedEffortProperty:
-            foreach (Schedule *s, m_schedules) {
+            for (Schedule *s : std::as_const(m_schedules)) {
                 s->clearPerformanceCache();
             }
         break;
@@ -1280,7 +1327,7 @@ void Node::changed(Node *node, int property) {
 Duration Node::plannedEffort(const Resource *resource, long id, EffortCostCalculationType type) const
 {
     Duration e;
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         e += n->plannedEffort(resource, id, type);
     }
     return e;
@@ -1289,7 +1336,7 @@ Duration Node::plannedEffort(const Resource *resource, long id, EffortCostCalcul
 Duration Node::plannedEffort(const Resource *resource, QDate date, long id, EffortCostCalculationType type) const
 {
     Duration e;
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         e += n->plannedEffort(resource, date, id, type);
     }
     return e;
@@ -1298,7 +1345,7 @@ Duration Node::plannedEffort(const Resource *resource, QDate date, long id, Effo
 Duration Node::plannedEffortTo(const Resource *resource, QDate date, long id, EffortCostCalculationType type) const
 {
     Duration e;
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         e += n->plannedEffortTo(resource, date, id, type);
     }
     return e;
@@ -1307,7 +1354,7 @@ Duration Node::plannedEffortTo(const Resource *resource, QDate date, long id, Ef
 EffortCost Node::plannedCost(long id, EffortCostCalculationType type) const
 {
     EffortCost ec;
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         ec += n->plannedCost(id, type);
     }
     return ec;
@@ -1321,13 +1368,13 @@ EffortCostMap Node::bcwsPrDay(long int id, EffortCostCalculationType type) const
 EffortCostMap Node::bcwsPrDay(long int id, EffortCostCalculationType type)
 {
     Schedule *s = schedule(id);
-    if (s == 0) {
+    if (s == nullptr) {
         return EffortCostMap();
     }
     EffortCostCache &ec = s->bcwsPrDayCache(type);
     if (! ec.cached) {
         ec.effortcostmap = EffortCostMap();
-        foreach (Node *n, m_nodes) {
+        for (Node *n : std::as_const(m_nodes)) {
             ec.effortcostmap += n->bcwsPrDay(id, type);
         }
         ec.cached = true;
@@ -1343,13 +1390,13 @@ EffortCostMap Node::bcwpPrDay(long int id, EffortCostCalculationType type) const
 EffortCostMap Node::bcwpPrDay(long int id, EffortCostCalculationType type)
 {
     Schedule *s = schedule(id);
-    if (s == 0) {
+    if (s == nullptr) {
         return EffortCostMap();
     }
     EffortCostCache &ec = s->bcwpPrDayCache(type);
     if (! ec.cached) {
         ec.effortcostmap = EffortCostMap();
-        foreach (Node *n, m_nodes) {
+        for (Node *n : std::as_const(m_nodes)) {
             ec.effortcostmap += n->bcwpPrDay(id, type);
         }
         ec.cached = true;
@@ -1365,13 +1412,13 @@ EffortCostMap Node::acwp(long id, EffortCostCalculationType type) const
 EffortCostMap Node::acwp(long id, EffortCostCalculationType type)
 {
     Schedule *s = schedule(id);
-    if (s == 0) {
+    if (s == nullptr) {
         return EffortCostMap();
     }
     EffortCostCache &ec = s->acwpCache(type);
     if (! ec.cached) {
         ec.effortcostmap = EffortCostMap();
-        foreach (Node *n, m_nodes) {
+        for (Node *n : std::as_const(m_nodes)) {
             ec.effortcostmap += n->acwp(id, type);
         }
         ec.cached = true;
@@ -1382,7 +1429,7 @@ EffortCostMap Node::acwp(long id, EffortCostCalculationType type)
 EffortCost Node::acwp(QDate date, long id) const
 {
     EffortCost ec;
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         ec += n->acwp(date, id);
     }
     return ec;
@@ -1432,7 +1479,7 @@ Estimate::Estimate(Node *parent)
     setOptimisticEstimate(8.0);
     
     m_type = Type_Effort;
-    m_calendar = 0;
+    m_calendar = nullptr;
     m_risktype = Risk_None;
 }
 
@@ -1455,7 +1502,7 @@ void Estimate::clear()
     setOptimisticEstimate(0.0);
     
     m_type = Type_Effort;
-    m_calendar = 0;
+    m_calendar = nullptr;
     m_risktype = Risk_None;
     m_unit = Duration::Unit_h;
     changed(Node::EstimateProperty);
@@ -1573,42 +1620,42 @@ void Estimate::setUnit(Duration::Unit unit)
 }
 
 bool Estimate::load(KoXmlElement &element, XMLLoaderObject &status) {
-    setType(element.attribute("type"));
-    setRisktype(element.attribute("risk"));
-    if (status.version() <= "0.6") {
-        m_unit = (Duration::Unit)(element.attribute("display-unit", QString().number(Duration::Unit_h)).toInt());
+    setType(element.attribute(QStringLiteral("type")));
+    setRisktype(element.attribute(QStringLiteral("risk")));
+    if (status.version() <= QStringLiteral("0.6")) {
+        m_unit = (Duration::Unit)(element.attribute(QStringLiteral("display-unit"), QString().number(Duration::Unit_h)).toInt());
         QList<qint64> s = status.project().standardWorktime()->scales();
-        m_expectedEstimate = scale(Duration::fromString(element.attribute("expected")), m_unit, s);
-        m_optimisticEstimate = scale(Duration::fromString(element.attribute("optimistic")), m_unit, s);
-        m_pessimisticEstimate = scale(Duration::fromString(element.attribute("pessimistic")), m_unit, s);
+        m_expectedEstimate = scale(Duration::fromString(element.attribute(QStringLiteral("expected"))), m_unit, s);
+        m_optimisticEstimate = scale(Duration::fromString(element.attribute(QStringLiteral("optimistic"))), m_unit, s);
+        m_pessimisticEstimate = scale(Duration::fromString(element.attribute(QStringLiteral("pessimistic"))), m_unit, s);
     } else {
-        if (status.version() <= "0.6.2") {
+        if (status.version() <= QStringLiteral("0.6.2")) {
             // 0 pos in unit is now Unit_Y, so add 3 to get the correct new unit
-            m_unit = (Duration::Unit)(element.attribute("unit", QString().number(Duration::Unit_ms - 3)).toInt() + 3);
+            m_unit = (Duration::Unit)(element.attribute(QStringLiteral("unit"), QString().number(Duration::Unit_ms - 3)).toInt() + 3);
         } else {
-            m_unit = Duration::unitFromString(element.attribute("unit"));
+            m_unit = Duration::unitFromString(element.attribute(QStringLiteral("unit")));
         }
-        m_expectedEstimate = element.attribute("expected", "0.0").toDouble();
-        m_optimisticEstimate = element.attribute("optimistic", "0.0").toDouble();
-        m_pessimisticEstimate = element.attribute("pessimistic", "0.0").toDouble();
+        m_expectedEstimate = element.attribute(QStringLiteral("expected"), QStringLiteral("0.0")).toDouble();
+        m_optimisticEstimate = element.attribute(QStringLiteral("optimistic"), QStringLiteral("0.0")).toDouble();
+        m_pessimisticEstimate = element.attribute(QStringLiteral("pessimistic"), QStringLiteral("0.0")).toDouble();
         
-        m_calendar = status.project().findCalendar(element.attribute("calendar-id"));
+        m_calendar = status.project().findCalendar(element.attribute(QStringLiteral("calendar-id")));
     }
     return true;
 }
 
 void Estimate::save(QDomElement &element) const {
-    QDomElement me = element.ownerDocument().createElement("estimate");
+    QDomElement me = element.ownerDocument().createElement(QStringLiteral("estimate"));
     element.appendChild(me);
-    me.setAttribute("expected", QString::number(m_expectedEstimate));
-    me.setAttribute("optimistic", QString::number(m_optimisticEstimate));
-    me.setAttribute("pessimistic", QString::number(m_pessimisticEstimate));
-    me.setAttribute("type", typeToString());
+    me.setAttribute(QStringLiteral("expected"), QString::number(m_expectedEstimate));
+    me.setAttribute(QStringLiteral("optimistic"), QString::number(m_optimisticEstimate));
+    me.setAttribute(QStringLiteral("pessimistic"), QString::number(m_pessimisticEstimate));
+    me.setAttribute(QStringLiteral("type"), typeToString());
     if (m_calendar) {
-        me.setAttribute("calendar-id", m_calendar->id());
+        me.setAttribute(QStringLiteral("calendar-id"), m_calendar->id());
     }
-    me.setAttribute("risk", risktypeToString());
-    me.setAttribute("unit", Duration::unitToString(m_unit));
+    me.setAttribute(QStringLiteral("risk"), risktypeToString());
+    me.setAttribute(QStringLiteral("unit"), Duration::unitToString(m_unit));
 }
 
 QString Estimate::typeToString(bool trans) const {
@@ -1622,8 +1669,8 @@ QString Estimate::typeToString(Estimate::Type typ, bool trans)
 
 QStringList Estimate::typeToStringList(bool trans) {
     return QStringList() 
-            << (trans ? i18n("Effort") : QString("Effort"))
-            << (trans ? i18n("Duration") : QString("Duration"));
+            << (trans ? i18n("Effort") : QStringLiteral("Effort"))
+            << (trans ? i18n("Duration") : QStringLiteral("Duration"));
 }
 
 void Estimate::setType(Type type)
@@ -1637,13 +1684,13 @@ void Estimate::setType(Type type)
 }
 
 void Estimate::setType(const QString& type) {
-    if (type == "Effort")
+    if (type == QStringLiteral("Effort"))
         setType(Type_Effort);
-    else if (type == "Duration" || /*old format*/ type == "FixedDuration")
+    else if (type == QStringLiteral("Duration") || /*old format*/ type == QStringLiteral("FixedDuration"))
         setType(Type_Duration);
-    else if (/*old format*/type == "Length")
+    else if (/*old format*/type == QStringLiteral("Length"))
         setType(Type_Duration);
-    else if (type == "Type_FixedDuration") // Typo, keep old xml files working
+    else if (type == QStringLiteral("Type_FixedDuration")) // Typo, keep old xml files working
         setType(Type_Duration);
     else
         setType(Type_Effort); // default
@@ -1655,15 +1702,15 @@ QString Estimate::risktypeToString(bool trans) const {
 
 QStringList Estimate::risktypeToStringList(bool trans) {
     return QStringList() 
-            << (trans ? i18n("None") : QString("None"))
-            << (trans ? i18n("Low") : QString("Low"))
-            << (trans ? i18n("High") : QString("High"));
+            << (trans ? i18n("None") : QStringLiteral("None"))
+            << (trans ? i18n("Low") : QStringLiteral("Low"))
+            << (trans ? i18n("High") : QStringLiteral("High"));
 }
 
 void Estimate::setRisktype(const QString& type) {
-    if (type == "High")
+    if (type == QStringLiteral("High"))
         setRisktype(Risk_High);
-    else if (type == "Low")
+    else if (type == QStringLiteral("Low"))
         setRisktype(Risk_Low);
     else
         setRisktype(Risk_None); // default
@@ -1883,14 +1930,14 @@ QList<qint64> Estimate::defaultScales()
 QList<qint64> Estimate::scales() const
 {
     QList<qint64> s;
-    if (m_type == Type_Duration && m_calendar == 0) {
+    if (m_type == Type_Duration && m_calendar == nullptr) {
         return s; // Use default scaling (24h a day...)
     }
-    if (m_parent == 0) {
+    if (m_parent == nullptr) {
         return s;
     }
     Project *p = static_cast<Project*>(m_parent->projectNode());
-    if (p == 0) {
+    if (p == nullptr) {
         return s;
     }
     s << p->standardWorktime()->scales();
