@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2005 - 2011 Dag Andersen <danders@get2net.dk>
- * Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2005-2011 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- * 
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KPTSCHEDULE_H
@@ -26,7 +13,8 @@
 #include "kptglobal.h"
 #include "kptcalendar.h"
 #include "kpteffortcostmap.h"
-#include "kptresource.h"
+#include "kptdatetime.h"
+#include "kptduration.h"
 
 #include <QList>
 #include <QMap>
@@ -34,7 +22,6 @@
 
 //#include "KoXmlReaderForward.h"
 class QDomElement;
-class QStringList;
 
 
 /// The main namespace
@@ -42,15 +29,15 @@ namespace KPlato
 {
 
 class Appointment;
-class DateTime;
-class Duration;
 class Node;
 class Project;
 class Task;
+class Resource;
 class ScheduleManager;
 class XMLLoaderObject;
 class SchedulerPlugin;
 class KPlatoXmlLoaderBase;
+class ProjectLoader_v0;
 
 /// Caches effortcost data (bcws, bcwp, acwp)
 class EffortCostCache {
@@ -94,13 +81,13 @@ public:
     Schedule *parent() const { return m_parent; }
     virtual bool isDeleted() const;
     virtual void setDeleted(bool on);
-    virtual bool recalculate() const { return m_parent == 0 ? false : m_parent->recalculate(); }
-    virtual DateTime recalculateFrom() const { return m_parent == 0 ? DateTime() : m_parent->recalculateFrom(); }
+    virtual bool recalculate() const { return m_parent == nullptr ? false : m_parent->recalculate(); }
+    virtual DateTime recalculateFrom() const { return m_parent == nullptr ? DateTime() : m_parent->recalculateFrom(); }
 
-    virtual long parentScheduleId() const { return m_parent == 0 ? NOTSCHEDULED : m_parent->parentScheduleId(); }
+    virtual long parentScheduleId() const { return m_parent == nullptr ? NOTSCHEDULED : m_parent->parentScheduleId(); }
 
-    virtual Resource *resource() const { return 0; }
-    virtual Node *node() const { return 0; }
+    virtual Resource *resource() const { return nullptr; }
+    virtual Node *node() const { return nullptr; }
     
     virtual bool isBaselined() const;
     virtual bool usePert() const;
@@ -115,7 +102,7 @@ public:
 
     bool isCritical() const { return positiveFloat == Duration::zeroDuration; }
 
-    virtual bool loadXML(const KoXmlElement &element, XMLLoaderObject &status);
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     virtual void saveXML(QDomElement &element) const;
     void saveCommonXML(QDomElement &element) const;
     void saveAppointments(QDomElement &element) const;
@@ -203,7 +190,7 @@ public:
     void setEarliestStart(DateTime &dt) { earlyStart = dt; }
     void setLatestFinish(DateTime &dt) { lateFinish = dt; }
 
-    virtual void initiateCalculation();
+    void initiateCalculation();
     virtual void calcResourceOverbooked();
     
     virtual void insertHardConstraint(Node *) {}
@@ -228,6 +215,7 @@ public:
     void setConstraintError(bool on) { constraintError = on; }
     void setNotScheduled(bool on) { notScheduled = on; }
     void setSchedulingError(bool on) { schedulingError = on; }
+    void setSchedulingCanceled(bool on) { schedulingCanceled = on; }
 
     void setPositiveFloat(KPlato::Duration f) { positiveFloat = f; }
     void setNegativeFloat(KPlato::Duration f) { negativeFloat = f; }
@@ -235,13 +223,13 @@ public:
 
     void setInCriticalPath(bool on = true) { inCriticalPath = on; }
 
-    virtual ScheduleManager *manager() const { return 0; }
+    virtual ScheduleManager *manager() const { return nullptr; }
     
     class PLANKERNEL_EXPORT Log {
         public:
             enum Type { Type_Debug = 0, Type_Info, Type_Warning, Type_Error };
             Log() 
-                : node(0), resource(0), severity(0), phase(-1)
+                : node(nullptr), resource(nullptr), severity(0), phase(-1)
             {}
             Log(const Node *n, int sev, const QString &msg, int ph = -1);
             Log(const Node *n, const Resource *r, int sev, const QString &msg, int ph = -1);
@@ -291,6 +279,8 @@ protected:
     friend class RecalculateProjectCmd;
     friend class ScheduleManager;
     friend class KPlatoXmlLoaderBase;
+    friend class ProjectLoader_v0;
+    friend class ResourceRequestCollection;
     /**
       * earlyStart is calculated by PERT/CPM.
       * A task may be scheduled to start later because of constraints
@@ -344,6 +334,8 @@ protected:
     bool effortNotMet;
     /// Set if some other scheduling error occurs
     bool schedulingError;
+    /// Set if scheduling was canceled
+    bool schedulingCanceled;
 
     DateTime workStartTime;
     DateTime workEndTime;
@@ -380,10 +372,10 @@ public:
     ~NodeSchedule() override;
 
     bool isDeleted() const override
-    { return m_parent == 0 ? true : m_parent->isDeleted(); }
+    { return m_parent == nullptr ? true : m_parent->isDeleted(); }
     void setDeleted(bool on) override;
 
-    bool loadXML(const KoXmlElement &element, XMLLoaderObject &status) override;
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     void saveXML(QDomElement &element) const override;
 
     // tasks------------>
@@ -423,7 +415,7 @@ public:
     ~ResourceSchedule() override;
 
     bool isDeleted() const override
-    { return m_parent == 0 ? true : m_parent->isDeleted(); }
+    { return m_parent == nullptr ? true : m_parent->isDeleted(); }
     void addAppointment(Schedule *node, const DateTime &start, const DateTime &end, double load = 100) override;
     void takeAppointment(Appointment *appointment, int type = Scheduling) override;
 
@@ -467,7 +459,7 @@ public:
     bool checkExternalAppointments() const override;
     bool usePert() const override;
 
-    bool loadXML(const KoXmlElement &element, XMLLoaderObject &status) override;
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     void saveXML(QDomElement &element) const override;
 
     void setManager(ScheduleManager *sm) { m_manager = sm; }
@@ -507,7 +499,7 @@ public:
     
     void clearCriticalPathList();
     QList<Node*> *currentCriticalPath() const;
-    void addCriticalPath(QList<Node*> *lst = 0);
+    void addCriticalPath(QList<Node*> *lst = nullptr);
     const QList< QList<Node*> > *criticalPathList() const { return &(m_pathlists); }
     QList<Node*> criticalPath(int index = 0) {
         QList<Node*> lst;
@@ -574,11 +566,13 @@ public:
         OverbookProperty,
         DistributionProperty,
         SchedulingModeProperty,
-        GranularityProperty
+        GranularityIndexProperty
     };
     Q_ENUM(Properties);
 
-    explicit ScheduleManager(Project &project, const QString name = QString());
+    enum Owner { OwnerPlan = 0, OwnerPortfolio = 1 };
+
+    explicit ScheduleManager(Project &project, const QString name = QString(), const ScheduleManager::Owner &creator = ScheduleManager::OwnerPlan);
     ~ScheduleManager() override;
     
     void setName(const QString& name);
@@ -592,7 +586,7 @@ public:
     void setParentManager(ScheduleManager *sm, int index = -1);
     ScheduleManager *parentManager() const { return m_parent; }
     
-    long scheduleId() const { return m_expected == 0 ? NOTSCHEDULED : m_expected->id(); }
+    long scheduleId() const { return m_expected == nullptr ? NOTSCHEDULED : m_expected->id(); }
     
     int removeChild(const ScheduleManager *sm);
     void insertChild(ScheduleManager *sm, int index = -1);
@@ -613,12 +607,12 @@ public:
     DateTime recalculateFrom() const { return m_recalculateFrom; }
     /// Set the datetime this schedule will be calculated from to @p dt
     void setRecalculateFrom(const DateTime &dt) { m_recalculateFrom = dt; }
-    long parentScheduleId() const { return m_parent == 0 ? NOTSCHEDULED : m_parent->scheduleId(); }
+    long parentScheduleId() const { return m_parent == nullptr ? NOTSCHEDULED : m_parent->scheduleId(); }
     void createSchedules();
     
     void setDeleted(bool on);
     
-    bool isScheduled() const { return m_expected == 0 ? false :  m_expected->isScheduled(); }
+    bool isScheduled() const { return m_expected == nullptr ? false :  m_expected->isScheduled(); }
 
     void setExpected(MainSchedule *sch);
     MainSchedule *expected() const { return m_expected; }
@@ -643,7 +637,7 @@ public:
     void setScheduling(bool on);
     bool scheduling() const { return m_scheduling; }
 
-    bool loadXML(KoXmlElement &element, XMLLoaderObject &status);
+    // NOTE: Saving is done here, loading is done using the XmlLoaderObject
     void saveXML(QDomElement &element) const;
     
     /// Save a workpackage document
@@ -679,23 +673,32 @@ public:
     void logAdded(const Schedule::Log &log);
 
     /// Create and load a MainSchedule
-    MainSchedule *loadMainSchedule(KoXmlElement &element, XMLLoaderObject &status);
+    //MainSchedule *loadMainSchedule(KoXmlElement &element, XMLLoaderObject &status);
 
     /// Load an existing MainSchedule
-    bool loadMainSchedule(MainSchedule *schedule, KoXmlElement &element, XMLLoaderObject &status);
+    //bool loadMainSchedule(MainSchedule *schedule, KoXmlElement &element, XMLLoaderObject &status);
 
     QMap< int, QString > phaseNames() const;
 
     /// Return a list of the supported granularities of the current scheduler
     QList<long unsigned int> supportedGranularities() const;
     /// Return current index of supported granularities of the selected scheduler
-    int granularity() const;
+    int granularityIndex() const;
     /// Set current index of supported granularities of the selected scheduler
-    void setGranularity(int duration);
+    void setGranularityIndex(int duration);
+
+    /// Return the granularity in millesconds
+    ulong granularity() const;
 
     bool schedulingMode() const;
     void setSchedulingMode(int mode);
 
+    DateTime scheduledStartTime() const;
+    DateTime scheduledEndTime() const;
+
+    Owner owner() const;
+    void setOwner(const ScheduleManager::Owner origin);
+
 public Q_SLOTS:
     /// Set maximum progress. Emits signal maxProgressChanged
     void setMaxProgress(int value);
@@ -740,17 +743,21 @@ protected:
     
     int m_calculationresult;
     int m_schedulingMode;
+    Owner m_owner = OwnerPlan;
 };
 
 
 } //namespace KPlato
 
 Q_DECLARE_TYPEINFO(KPlato::Schedule::Log, Q_MOVABLE_TYPE);
-Q_DECLARE_METATYPE(KPlato::Schedule::Log);
+Q_DECLARE_METATYPE(KPlato::Schedule::Log)
 
 PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::Schedule *s);
 PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::Schedule &s);
 
 PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::Schedule::Log &log);
 
+PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::ScheduleManager &sm);
+PLANKERNEL_EXPORT QDebug operator<<(QDebug dbg, const KPlato::ScheduleManager *sm);
+
 #endif
