@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2015 Friedrich W. H. Kossebau <kossebau@kde.org>
+   SPDX-FileCopyrightText: 2015 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -67,7 +54,7 @@ QString KoComponentData::componentDisplayName() const
 const KSharedConfig::Ptr& KoComponentData::config() const
 {
     if (!d->sharedConfig) {
-        d->sharedConfig = KSharedConfig::openConfig(d->aboutData.componentName() + QLatin1String("rc"));
+        d->sharedConfig = KSharedConfig::openConfig(d->aboutData.componentName() + QStringLiteral("rc"));
     }
 
     return d->sharedConfig;
