@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2000-2005 David Faure <faure@kde.org>
-   Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
-   Copyright (C) 2010 Boudewijn Rempt <boud@kogmbh.com>
+   SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 2000-2005 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2007 Thorsten Zachmann <zachmann@kde.org>
+   SPDX-FileCopyrightText: 2010 Boudewijn Rempt <boud@kogmbh.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KODOCUMENT_H
@@ -63,6 +50,8 @@ class QDomDocument;
 
 namespace KPlato {
     class Project;
+    class SchedulerPlugin;
+    class ScheduleManager;
 }
 
 class KoVersionInfo
@@ -102,9 +91,6 @@ public:
     explicit KoDocument(KoPart *parent,
                         KUndo2Stack *undoStack = new KUndo2Stack());
 
-    virtual KPlato::Project *project() const { return nullptr; }
-    virtual QString projectName() const { return QString(); }
-
     /**
      *  Destructor.
      *
@@ -113,6 +99,13 @@ public:
      */
     ~KoDocument() override;
 
+    void setPassword(const QString password);
+    QString password() const;
+
+    virtual KPlato::Project *project() const { return nullptr; }
+    virtual QString projectName() const { return QString(); }
+    virtual QMap<QString, KPlato::SchedulerPlugin*> schedulerPlugins() const { return QMap<QString, KPlato::SchedulerPlugin*>(); }
+
     /// XXX: Temporary!
     KoPart *documentPart() const;
 
@@ -155,14 +148,6 @@ public:
      */
     virtual void setReadWrite(bool readwrite = true);
 
-    /**
-     * To be preferred when a document exists. It is fast when calling
-     * it multiple times since it caches the result that readNativeFormatMimeType()
-     * delivers.
-     * This comes from the X-KDE-NativeMimeType key in the .desktop file.
-     */
-    virtual QByteArray nativeFormatMimeType() const = 0;
-
     /**
      * Returns the OASIS OpenDocument mimetype of the document, if supported
      * This comes from the X-KDE-NativeOasisMimeType key in the
@@ -268,14 +253,6 @@ public:
      */
     virtual QPixmap generatePreview(const QSize& size);
 
-    /**
-     *  Paints the data itself.
-     *  It's this method that %Calligra Parts have to implement.
-     *
-     *  @param painter     The painter object onto which will be drawn.
-     *  @param rect        The rect that should be used in the painter object.
-     */
-    virtual void paintContent(QPainter &painter, const QRect &rect) = 0;
 
     /**
      *  Tells the document that its title has been modified, either because
@@ -308,7 +285,7 @@ public:
      *  @param url An internal url, like tar:/1/2
      */
     virtual bool loadFromStore(KoStore *store, const QString& url);
-
+    virtual bool loadEmbeddedDocument(KoStore */*store*/, const QString& /*dir*/) { return false; }
     /**
      *  @brief Loads an OASIS document from a store.
      *  This is used for both the main document and embedded objects.
@@ -352,6 +329,7 @@ public:
      *  @param version the DTD version (usually the application's version).
      */
     static QDomDocument createDomDocument(const QString& appName, const QString& tagName, const QString& version);
+    static QDomDocument createDomDocument(const char *appName, const QString& tagName, const QString& version);
 
     /**
      *  The first thing to do in loadOasis is get hold of the office:body tag, then its child.
@@ -458,6 +436,9 @@ public:
     void setProgressProxy(KoProgressProxy *progressProxy);
     KoProgressProxy* progressProxy() const;
 
+    void setProgressEnabled(bool enable);
+    bool progressEnabled() const;
+
     /**
      * Return true if url() is a real filename, false if url() is
      * an internal url in the store, like "tar:/..."
@@ -649,7 +630,7 @@ Q_SIGNALS:
 
     /**
      * Progress info while loading or saving. The value is in percents (i.e. a number between 0 and 100)
-     * Your KoDocument-derived class should emit the signal now and then during load/save.
+     * Your KoDocument-derived class should Q_EMIT the signal now and then during load/save.
      * KoMainWindow will take care of displaying a progress bar automatically.
      */
     void sigProgress(int value);
@@ -779,6 +760,8 @@ Q_SIGNALS:
     void completed();
     void canceled(const QString &);
 
+    void scheduleManagerChanged(KPlato::ScheduleManager *sm);
+
 private Q_SLOTS:
 
     void slotAutoSave();
@@ -788,6 +771,8 @@ private Q_SLOTS:
 
 protected:
     bool oldLoadAndParse(KoStore *store, const QString& filename, KoXmlDocument& doc);
+    bool oldLoadAndParse(KoStore *store, const char *filename, KoXmlDocument& doc);
+
 private:
     bool saveToStream(QIODevice *dev);
 
