@@ -1,21 +1,8 @@
 /* This file is part of the Calligra libraries
-   Copyright (C) 2001 Werner Trobin <trobin@kde.org>
+   SPDX-FileCopyrightText: 2001 Werner Trobin <trobin@kde.org>
                  2002 Werner Trobin <trobin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __KO_FILTER_H__
@@ -72,6 +59,12 @@ public:
                             UnexpectedOpcode, UserCancelled, OutOfMemory,
                             PasswordProtected, InvalidFormat, FilterEntryNull,
                             NoDocumentCreated, DownloadFailed, FilterCreationError,
+                            ReadTimeout,
+                            UnknownError,
+                            JavaJarNotFound,
+                            JavaJarFailed,
+                            JavaExecutionError,
+                            JdbcOdbcDriverException,
                             JustInCaseSomeBrokenCompilerUsesLessThanAByte = 255
                           };
 
@@ -92,7 +85,7 @@ public:
 
     /**
      * Set the updater to which the filter will report progress.
-     * Every emit of the sigProgress signal is reported to the updater.
+     * Every Q_EMIT of the sigProgress signal is reported to the updater.
      */
     void setUpdater(const QPointer<KoUpdater>& updater);
 
@@ -110,7 +103,7 @@ protected:
     /**
      * This is the constructor your filter has to call, obviously.
      */
-    KoFilter(QObject *parent = 0);
+    KoFilter(QObject *parent = nullptr);
 
     /**
      * Use this pointer to access all information about input/output
