@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 Dag Andersen <danders@get2net.dk>
-  Copyright (C) 2011 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2007 Dag Andersen <dag.andersen@kdemail.net>
+  SPDX-FileCopyrightText: 2011 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTACCOUNTSMODEL_H
@@ -65,7 +52,7 @@ class PLANMODELS_EXPORT AccountItemModel : public ItemModelBase
 {
     Q_OBJECT
 public:
-    explicit AccountItemModel(QObject *parent = 0);
+    explicit AccountItemModel(QObject *parent = nullptr);
     ~AccountItemModel() override;
 
     const QMetaEnum columnMap() const override;
@@ -87,7 +74,7 @@ public:
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
     Account *account(const QModelIndex &index) const;
-    QModelIndex insertAccount(Account *account, Account *parent = 0, int index = -1);
+    QModelIndex insertAccount(Account *account, Account *parent = nullptr, int index = -1);
     void removeAccounts(QList<Account*> lst);
     
 protected Q_SLOTS:
@@ -117,7 +104,7 @@ public:
     enum EndMode { EndMode_Project = 0, EndMode_Date = 1, EndMode_CurrentDate = 2 };
     enum ShowMode { ShowMode_Actual = 0, ShowMode_Planned = 1, ShowMode_Both = 2, ShowMode_Deviation = 3 };
 
-    explicit CostBreakdownItemModel(QObject *parent = 0);
+    explicit CostBreakdownItemModel(QObject *parent = nullptr);
     ~CostBreakdownItemModel() override;
 
     enum Properties {
