@@ -1,20 +1,7 @@
 /* This file is part of the Calligra project
- * Copyright (c) 2008, 2012 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2008, 2012 Dag Andersen <dag.andersen@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -174,7 +161,7 @@ QVariant ChartItemModel::data(const QModelIndex &index, int role) const
             QLocale locale;
             // TODO: temporary workaround while KLocale/money logic still used
             Locale *planLocale;
-            Locale *tmpPlanLocale = 0;
+            Locale *tmpPlanLocale = nullptr;
             if (project()) {
                 planLocale = project()->locale();
             } else {
@@ -278,16 +265,16 @@ QVariant ChartItemModel::headerData(int section, Qt::Orientation orientation, in
     } else if (role == Qt::EditRole) {
         if (orientation == Qt::Horizontal) {
             switch (section) {
-                case BCWSCost: return "BCWS Cost";
-                case BCWPCost: return "BCWP Cost";
-                case ACWPCost: return "ACWP Cost";
-                case BCWSEffort: return "BCWS Effort";
-                case BCWPEffort: return "BCWP Effort";
-                case ACWPEffort: return "ACWP Effort";
-                case SPICost: return "SPI Cost";
-                case CPICost: return "CPI Cost";
-                case SPIEffort: return "SPI Effort";
-                case CPIEffort: return "CPI Effort";
+                case BCWSCost: return QStringLiteral("BCWS Cost");
+                case BCWPCost: return QStringLiteral("BCWP Cost");
+                case ACWPCost: return QStringLiteral("ACWP Cost");
+                case BCWSEffort: return QStringLiteral("BCWS Effort");
+                case BCWPEffort: return QStringLiteral("BCWP Effort");
+                case ACWPEffort: return QStringLiteral("ACWP Effort");
+                case SPICost: return QStringLiteral("SPI Cost");
+                case CPICost: return QStringLiteral("CPI Cost");
+                case SPIEffort: return QStringLiteral("SPI Effort");
+                case CPIEffort: return QStringLiteral("CPI Effort");
                 default: return QVariant();
             }
         } else {
@@ -397,7 +384,7 @@ void ChartItemModel::slotNodeChanged(Node *node)
         endResetModel();
         return;
     }
-    foreach (Node *n, m_nodes) {
+    for (Node *n : std::as_const(m_nodes)) {
         if (node->isChildOf(n)) {
             beginResetModel();
             calculate();
@@ -407,14 +394,14 @@ void ChartItemModel::slotNodeChanged(Node *node)
     }
 }
 
-void ChartItemModel::slotResourceChanged(Resource*)
+void ChartItemModel::slotResourceChanged()
 {
     beginResetModel();
     calculate();
     endResetModel();
 }
 
-void ChartItemModel::slotResourceRemoved(const Resource*)
+void ChartItemModel::slotResourceRemoved()
 {
     beginResetModel();
     calculate();
@@ -444,9 +431,9 @@ void ChartItemModel::calculate()
     m_acwp.clear();
     if (m_manager) {
         if (m_project) {
-            foreach (Node *n, m_nodes) {
+            for (Node *n : std::as_const(m_nodes)) {
                 bool skip = false;
-                foreach (Node *p, m_nodes) {
+                for (Node *p : std::as_const(m_nodes)) {
                     if (n->isChildOf(p)) {
                         skip = true;
                         break;
@@ -498,6 +485,7 @@ int PerformanceDataCurrentDateModel::columnCount(const QModelIndex &/*parent*/)
 
 QModelIndex PerformanceDataCurrentDateModel::parent(const QModelIndex &idx) const
 {
+    Q_UNUSED(idx)
     return QModelIndex();
 }
 
