@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007, 2012 Dag Andersen <danders@get2net>
+  SPDX-FileCopyrightText: 2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -50,7 +37,7 @@ static const quintptr ProjectItemId  = static_cast<quintptr>(-2);
 
 CriticalPathItemModel::CriticalPathItemModel(QObject *parent)
     : ItemModelBase(parent),
-    m_manager(0)
+    m_manager(nullptr)
 {
 /*    connect(this, SIGNAL(modelAboutToBeReset()), SLOT(slotAboutToBeReset()));
     connect(this, SIGNAL(modelReset()), SLOT(slotReset()));*/
@@ -120,7 +107,7 @@ void CriticalPathItemModel::setManager(ScheduleManager *sm)
     debugPlan<<this;
     m_manager = sm;
     m_nodemodel.setManager(sm);
-    if (m_project == 0 || m_manager == 0) {
+    if (m_project == nullptr || m_manager == nullptr) {
         m_path.clear();
     } else {
         m_path = m_project->criticalPath(m_manager->scheduleId(), 0);
@@ -136,7 +123,7 @@ QModelIndex CriticalPathItemModel::parent(const QModelIndex &) const
 
 QModelIndex CriticalPathItemModel::index(int row, int column, const QModelIndex &parent) const
 {
-    if (m_project == 0 || column < 0 || column >= columnCount() || row < 0) {
+    if (m_project == nullptr || column < 0 || column >= columnCount() || row < 0) {
         return QModelIndex();
     }
     if (parent.isValid()) {
@@ -190,7 +177,7 @@ QVariant CriticalPathItemModel::variance(int role) const
         case Qt::DisplayRole:
         case Qt::ToolTipRole: {
             double v = 0.0;
-            foreach (Node *n, m_path) {
+            for (Node *n : std::as_const(m_path)) {
                 long id = m_manager->scheduleId();
                 v += n->variance(id, presentationUnit(m_project->duration(id)));
             }
@@ -199,7 +186,7 @@ QVariant CriticalPathItemModel::variance(int role) const
         }
         case Qt::EditRole: {
             double v = 0.0;
-            foreach (Node *n, m_path) {
+            for (Node *n : std::as_const(m_path)) {
                 v += n->variance(m_manager->scheduleId());
             }
             return v;
@@ -215,7 +202,7 @@ QVariant CriticalPathItemModel::notUsed(int role) const
 {
     switch (role) {
         case Qt::DisplayRole:
-            return "";
+            return QLatin1String("");
         default:
             return QVariant();
     }
@@ -232,7 +219,7 @@ QVariant CriticalPathItemModel::data(const QModelIndex &index, int role) const
         return alignment(index.column());
     }
     Node *n = node(index);
-    if (n == 0) {
+    if (n == nullptr) {
         switch (index.column()) {
             case NodeModel::NodeName: result = name(role); break;
             case NodeModel::NodeDuration: result = duration(role); break;
@@ -244,7 +231,7 @@ QVariant CriticalPathItemModel::data(const QModelIndex &index, int role) const
         result = m_nodemodel.data(n, index.column(), role);
     }
     if (result.isValid()) {
-        if (role == Qt::DisplayRole && result.type() == QVariant::String && result.toString().isEmpty()) {
+        if (role == Qt::DisplayRole && result.typeId() == QMetaType::QString && result.toString().isEmpty()) {
             // HACK to show focus in empty cells
             result = ' ';
         }
@@ -294,7 +281,7 @@ int CriticalPathItemModel::rowCount(const QModelIndex &parent) const
 Node *CriticalPathItemModel::node(const QModelIndex &index) const
 {
     if (! index.isValid()) {
-        return 0;
+        return nullptr;
     }
     return m_path.value(index.row());
 }
@@ -302,18 +289,18 @@ Node *CriticalPathItemModel::node(const QModelIndex &index) const
 void CriticalPathItemModel::slotNodeChanged(Node *node)
 {
     debugPlan;
-    if (node == 0 || node->type() == Node::Type_Project || ! m_path.contains(node)) {
+    if (node == nullptr || node->type() == Node::Type_Project || ! m_path.contains(node)) {
         return;
     }
     int row = m_path.indexOf(node);
-    emit dataChanged(createIndex(row, 0, node), createIndex(row, columnCount() - 1, node));
+    Q_EMIT dataChanged(createIndex(row, 0, node), createIndex(row, columnCount() - 1, node));
 }
 
 
 //-----------------------------
 PertResultItemModel::PertResultItemModel(QObject *parent)
     : ItemModelBase(parent),
-    m_manager(0)
+    m_manager(nullptr)
 {
 /*    connect(this, SIGNAL(modelAboutToBeReset()), SLOT(slotAboutToBeReset()));
     connect(this, SIGNAL(modelReset()), SLOT(slotReset()));*/
@@ -399,7 +386,7 @@ void PertResultItemModel::setManager(ScheduleManager *sm)
 void PertResultItemModel::clear()
 {
     debugPlan<<this;
-    foreach (NodeList *l, m_top) {
+    for (NodeList *l : std::as_const(m_top)) {
         int c = l->count();
         if (c > 0) {
             // FIXME: gives error msg:
@@ -423,10 +410,10 @@ void PertResultItemModel::clear()
 void PertResultItemModel::refresh()
 {
     clear();
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         return;
     }
-    long id = m_manager == 0 ? -1 : m_manager->scheduleId();
+    long id = m_manager == nullptr ? -1 : m_manager->scheduleId();
     debugPlan<<id;
     if (id == -1) {
         return;
@@ -442,7 +429,8 @@ void PertResultItemModel::refresh()
         }
         if (lst->isEmpty()) debugPlan<<"No critical path";
     }
-    foreach(Node* n, m_project->allNodes()) {
+    const QList<Node*> nodes = m_project->allNodes();
+    for (Node* n : nodes) {
         if (n->type() != Node::Type_Task && n->type() != Node::Type_Milestone) {
             continue;
         }
@@ -467,7 +455,8 @@ void PertResultItemModel::refresh()
         debugPlan<<m_top;
         beginInsertRows(QModelIndex(), 0, m_top.count() -1);
         endInsertRows();
-        foreach (NodeList *l, m_top) {
+        
+        for (NodeList *l : std::as_const(m_top)) {
             int c = l->count();
             if (c > 0) {
                 beginInsertRows(index(l), 0, c-1);
@@ -495,7 +484,7 @@ QModelIndex PertResultItemModel::parent(const QModelIndex &index) const
     if (row < 0) {
         return QModelIndex(); // top level has no parent
     }
-    if (m_top.value(row) == 0) {
+    if (m_top.value(row) == nullptr) {
         return QModelIndex();
     }
     return createIndex(row, 0, ListItemId);
@@ -503,7 +492,7 @@ QModelIndex PertResultItemModel::parent(const QModelIndex &index) const
 
 QModelIndex PertResultItemModel::index(int row, int column, const QModelIndex &parent) const
 {
-    if (m_project == 0 || column < 0 || column >= columnCount() || row < 0) {
+    if (m_project == nullptr || column < 0 || column >= columnCount() || row < 0) {
         return QModelIndex();
     }
     if (! parent.isValid()) {
@@ -522,7 +511,7 @@ QModelIndex PertResultItemModel::index(int row, int column, const QModelIndex &p
         return QModelIndex();
     }
     NodeList *l = m_top.value(parent.row());
-    if (l == 0) {
+    if (l == nullptr) {
         return QModelIndex();
     }
     QModelIndex i = createIndex(row, column, parent.row());
@@ -545,7 +534,7 @@ QModelIndex PertResultItemModel::index(int row, int column, const QModelIndex &p
 
 QModelIndex PertResultItemModel::index(const NodeList *lst) const
 {
-    if (m_project == 0 || lst == 0) {
+    if (m_project == nullptr || lst == nullptr) {
         return QModelIndex();
     }
     NodeList *l = const_cast<NodeList*>(lst);
@@ -732,7 +721,7 @@ QVariant PertResultItemModel::data(const QModelIndex &index, int role) const
         return alignment(index.column());
     }
     Node *n = node(index);
-    if (n == 0) {
+    if (n == nullptr) {
         switch (index.column()) {
             case 0: return name(index.row(), role);
             default: break;
@@ -752,7 +741,7 @@ QVariant PertResultItemModel::data(const QModelIndex &index, int role) const
         }
     }
     if (result.isValid()) {
-        if (role == Qt::DisplayRole && result.type() == QVariant::String && result.toString().isEmpty()) {
+        if (role == Qt::DisplayRole && result.typeId() == QMetaType::QString && result.toString().isEmpty()) {
             // HACK to show focus in empty cells
             result = ' ';
         }
@@ -786,9 +775,9 @@ QVariant PertResultItemModel::alignment(int column) const
 QAbstractItemDelegate *PertResultItemModel::createDelegate(int column, QWidget * /*parent*/) const
 {
     switch (column) {
-        default: return 0;
+        default: return nullptr;
     }
-    return 0;
+    return nullptr;
 }
 
 int PertResultItemModel::columnCount(const QModelIndex &) const
@@ -845,25 +834,25 @@ NodeList *PertResultItemModel::list(const QModelIndex &index) const
         return m_top.value(index.row());
     }
     //debugPlan<<index<<"is not list";
-    return 0;
+    return nullptr;
 }
 
 Node *PertResultItemModel::node(const QModelIndex &index) const
 {
     if (! index.isValid()) {
-        return 0;
+        return nullptr;
     }
     if (index.internalId() == ProjectItemId) {
         return m_project;
     }
     if (index.internalId() == 0) {
-        return 0;
+        return nullptr;
     }
     NodeList *l = m_top.value(index.internalId());
     if (l) {
         return l->value(index.row());
     }
-    return 0;
+    return nullptr;
 }
 
 void PertResultItemModel::slotNodeChanged(Node *)
@@ -874,7 +863,7 @@ void PertResultItemModel::slotNodeChanged(Node *)
         return;
     }
     int row = node->getParent()->findChildNode(node);
-    emit dataChanged(createIndex(row, 0, node), createIndex(row, columnCount() - 1, node));*/
+    Q_EMIT dataChanged(createIndex(row, 0, node), createIndex(row, columnCount() - 1, node));*/
 }
 
 
