@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007, 2012 Dag Andersen <danders@get2net.dk>
+  SPDX-FileCopyrightText: 2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -180,7 +167,7 @@ void TaskStatusItemModel::setScheduleManager(ScheduleManager *sm)
 
 void TaskStatusItemModel::clear()
 {
-    foreach (NodeMap *l, m_top) {
+    for (NodeMap *l : std::as_const(m_top)) {
         int c = l->count();
         if (c > 0) {
             //FIXME: gives error msg:
@@ -216,7 +203,7 @@ void TaskStatusItemModel::setNow()
 void TaskStatusItemModel::refresh()
 {
     clear();
-    if (m_project == 0) {
+    if (m_project == nullptr) {
         return;
     }
     m_id = m_nodemodel.id();
@@ -227,7 +214,8 @@ void TaskStatusItemModel::refresh()
     const QDate begin = m_nodemodel.now().addDays(-m_period);
     const QDate end = m_nodemodel.now().addDays(m_period);
 
-    foreach(Node* n, m_project->allNodes()) {
+    const QList<Node*> nodes = m_project->allNodes();
+    for (Node* n : nodes) {
         if (n->type() != Node::Type_Task && n->type() != Node::Type_Milestone) {
             continue;
         }
@@ -237,7 +225,7 @@ void TaskStatusItemModel::refresh()
             m_top.at(status)->insert(task->wbsCode(), task);
         }
     }
-    foreach (NodeMap *l, m_top) {
+    for (NodeMap *l : std::as_const(m_top)) {
         int c = l->count();
         if (c > 0) {
             debugPlan<<index(l)<<0<<c-1;
@@ -245,7 +233,7 @@ void TaskStatusItemModel::refresh()
             endInsertRows();
         }
     }
-    emit layoutChanged(); //HACK to get views updated
+    Q_EMIT layoutChanged(); //HACK to get views updated
 }
 
 Qt::ItemFlags TaskStatusItemModel::flags(const QModelIndex &index) const
@@ -254,7 +242,7 @@ Qt::ItemFlags TaskStatusItemModel::flags(const QModelIndex &index) const
     flags &= ~(Qt::ItemIsEditable | Qt::ItemIsDropEnabled);
     flags |= Qt::ItemIsDragEnabled;
     Node *n = node(index);
-    if (! m_readWrite || n == 0 || m_id == -1 || ! n->isScheduled(m_id)) {
+    if (! m_readWrite || n == nullptr || m_id == -1 || ! n->isScheduled(m_id)) {
         return flags;
     }
     if (n->type() != Node::Type_Task && n->type() != Node::Type_Milestone) {
@@ -304,17 +292,17 @@ QModelIndex TaskStatusItemModel::parent(const QModelIndex &index) const
         return QModelIndex(); // top level has no parent
     }
     Node *n = node(index);
-    if (n == 0) {
+    if (n == nullptr) {
         return QModelIndex();
     }
-    NodeMap *lst = 0;
-    foreach (NodeMap *l, m_top) {
+    NodeMap *lst = nullptr;
+    for (NodeMap *l : std::as_const(m_top)) {
         if (CONTAINS((*l), n)) {
             lst = l;
             break;
         }
     }
-    if (lst == 0) {
+    if (lst == nullptr) {
         return QModelIndex();
     }
     return createIndex(m_top.indexOf(lst), 0, lst);
@@ -323,7 +311,7 @@ QModelIndex TaskStatusItemModel::parent(const QModelIndex &index) const
 QModelIndex TaskStatusItemModel::index(int row, int column, const QModelIndex &parent) const
 {
     //debugPlan<<row<<column<<parent;
-    if (m_project == 0 || column < 0 || column >= columnCount() || row < 0) {
+    if (m_project == nullptr || column < 0 || column >= columnCount() || row < 0) {
         return QModelIndex();
     }
     if (! parent.isValid()) {
@@ -333,7 +321,7 @@ QModelIndex TaskStatusItemModel::index(int row, int column, const QModelIndex &p
         return createIndex(row, column, m_top.value(row));
     }
     NodeMap *l = list(parent);
-    if (l == 0) {
+    if (l == nullptr) {
         return QModelIndex();
     }
     if (row >= rowCount(parent)) {
@@ -342,16 +330,16 @@ QModelIndex TaskStatusItemModel::index(int row, int column, const QModelIndex &p
     }
     const QList<Node*> &nodes = l->values();
     QModelIndex i = createIndex(row, column, nodes.value(row));
-    Q_ASSERT(i.internalPointer() != 0);
+    Q_ASSERT(i.internalPointer() != nullptr);
     return i;
 }
 
 QModelIndex TaskStatusItemModel::index(const Node *node) const
 {
-    if (m_project == 0 || node == 0) {
+    if (m_project == nullptr || node == nullptr) {
         return QModelIndex();
     }
-    foreach(NodeMap *l, m_top) {
+    for(NodeMap *l : std::as_const(m_top)) {
         const QList<Node*> &nodes = l->values();
         int row = nodes.indexOf(const_cast<Node*>(node));
         if (row != -1) {
@@ -363,7 +351,7 @@ QModelIndex TaskStatusItemModel::index(const Node *node) const
 
 QModelIndex TaskStatusItemModel::index(const NodeMap *lst) const
 {
-    if (m_project == 0 || lst == 0) {
+    if (m_project == nullptr || lst == nullptr) {
         return QModelIndex();
     }
     NodeMap *l = const_cast<NodeMap*>(lst);
@@ -398,18 +386,21 @@ bool TaskStatusItemModel::setCompletion(Node *node, const QVariant &value, int r
         Completion &c = static_cast<Task*>(node)->completion();
         QDateTime dt = QDateTime::currentDateTime();
         QDate date = dt.date();
+        bool stateChanged = false;
         // xgettext: no-c-format
         MacroCommand *m = new MacroCommand(kundo2_i18n("Modify completion"));
         if (! c.isStarted()) {
             m->addCommand(new ModifyCompletionStartedCmd(c, true));
             m->addCommand(new ModifyCompletionStartTimeCmd(c, dt));
+            stateChanged = true;
         }
         m->addCommand(new ModifyCompletionPercentFinishedCmd(c, date, value.toInt()));
         if (value.toInt() == 100) {
             m->addCommand(new ModifyCompletionFinishedCmd(c, true));
             m->addCommand(new ModifyCompletionFinishTimeCmd(c, dt));
+            stateChanged = true;
         }
-        emit executeCommand(m); // also adds a new entry if necessary
+        Q_EMIT executeCommand(m); // also adds a new entry if necessary
         if (c.entrymode() != Completion::EnterEffortPerResource) {
             Duration planned = static_cast<Task*>(node)->plannedEffort(m_nodemodel.id());
             Duration actual = (planned * value.toInt()) / 100;
@@ -421,6 +412,9 @@ bool TaskStatusItemModel::setCompletion(Node *node, const QVariant &value, int r
             cmd->execute();
             m->addCommand(cmd);
         }
+        if (stateChanged) {
+            Q_EMIT this->stateChanged(node);
+        }
         return true;
     }
     if (node->type() == Node::Type_Milestone) {
@@ -434,7 +428,8 @@ bool TaskStatusItemModel::setCompletion(Node *node, const QVariant &value, int r
             m->addCommand(new ModifyCompletionFinishedCmd(c, true));
             m->addCommand(new ModifyCompletionFinishTimeCmd(c, dt));
             m->addCommand(new ModifyCompletionPercentFinishedCmd(c, date, 100));
-            emit executeCommand(m); // also adds a new entry if necessary
+            Q_EMIT executeCommand(m); // also adds a new entry if necessary
+            Q_EMIT stateChanged(node);
             return true;
         }
         return false;
@@ -449,7 +444,7 @@ bool TaskStatusItemModel::setRemainingEffort(Node *node, const QVariant &value,
         double d(value.toList()[0].toDouble());
         Duration::Unit unit = static_cast<Duration::Unit>(value.toList()[1].toInt());
         Duration dur(d, unit);
-        emit executeCommand(new ModifyCompletionRemainingEffortCmd(t->completion(), QDate::currentDate(), dur, kundo2_i18n("Modify remaining effort")));
+        Q_EMIT executeCommand(new ModifyCompletionRemainingEffortCmd(t->completion(), QDate::currentDate(), dur, kundo2_i18n("Modify remaining effort")));
         return true;
     }
     return false;
@@ -462,7 +457,7 @@ bool TaskStatusItemModel::setActualEffort(Node *node, const QVariant &value, int
         double d(value.toList()[0].toDouble());
         Duration::Unit unit = static_cast<Duration::Unit>(value.toList()[1].toInt());
         Duration dur(d, unit);
-        emit executeCommand(new ModifyCompletionActualEffortCmd(t->completion(), QDate::currentDate(), dur, kundo2_i18n("Modify actual effort")));
+        Q_EMIT executeCommand(new ModifyCompletionActualEffortCmd(t->completion(), QDate::currentDate(), dur, kundo2_i18n("Modify actual effort")));
         return true;
     }
     return false;
@@ -473,7 +468,7 @@ bool TaskStatusItemModel::setStartedTime(Node *node, const QVariant &value, int
     switch (role) {
         case Qt::EditRole: {
             Task *t = qobject_cast<Task*>(node);
-            if (t == 0) {
+            if (t == nullptr) {
                 return false;
             }
             MacroCommand *m = new MacroCommand(kundo2_i18n("Modify actual start time"));
@@ -489,7 +484,7 @@ bool TaskStatusItemModel::setStartedTime(Node *node, const QVariant &value, int
                     m->addCommand(new AddCompletionEntryCmd(t->completion(), value.toDate(), e));
                 }
             }
-            emit executeCommand(m);
+            Q_EMIT executeCommand(m);
             return true;
         }
     }
@@ -501,7 +496,7 @@ bool TaskStatusItemModel::setFinishedTime(Node *node, const QVariant &value, int
     switch (role) {
         case Qt::EditRole: {
             Task *t = qobject_cast<Task*>(node);
-            if (t == 0) {
+            if (t == nullptr) {
                 return false;
             }
             MacroCommand *m = new MacroCommand(kundo2_i18n("Modify actual finish time"));
@@ -517,7 +512,7 @@ bool TaskStatusItemModel::setFinishedTime(Node *node, const QVariant &value, int
                 m->addCommand(new ModifyCompletionStartedCmd(t->completion(), true));
                 m->addCommand(new ModifyCompletionStartTimeCmd(t->completion(), value.toDateTime()));
             }
-            emit executeCommand(m);
+            Q_EMIT executeCommand(m);
             return true;
         }
     }
@@ -534,7 +529,7 @@ QVariant TaskStatusItemModel::data(const QModelIndex &index, int role) const
         return alignment(index.column());
     }
     Node *n = node(index);
-    if (n == 0) {
+    if (n == nullptr) {
         switch (index.column()) {
             case NodeModel::NodeName: return name(index.row(), role);
             default: break;
@@ -612,9 +607,9 @@ QAbstractItemDelegate *TaskStatusItemModel::createDelegate(int column, QWidget *
         case NodeModel::NodeCompleted: return new TaskCompleteDelegate(parent);
         case NodeModel::NodeRemainingEffort: return new DurationSpinBoxDelegate(parent);
         case NodeModel::NodeActualEffort: return new DurationSpinBoxDelegate(parent);
-        default: return 0;
+        default: return nullptr;
     }
-    return 0;
+    return nullptr;
 }
 
 int TaskStatusItemModel::columnCount(const QModelIndex &) const
@@ -644,7 +639,9 @@ Qt::DropActions TaskStatusItemModel::supportedDropActions() const
 
 QStringList TaskStatusItemModel::mimeTypes() const
 {
-    return ItemModelBase::mimeTypes();
+    return QStringList()
+            << QStringLiteral("text/html")
+            << QStringLiteral("text/plain");
 }
 
 QMimeData *TaskStatusItemModel::mimeData(const QModelIndexList & indexes) const
@@ -670,13 +667,13 @@ NodeMap *TaskStatusItemModel::list(const QModelIndex &index) const
             return static_cast<NodeMap*>(index.internalPointer());
         }
     }
-    return 0;
+    return nullptr;
 }
 
 Node *TaskStatusItemModel::node(const QModelIndex &index) const
 {
     if (index.isValid()) {
-        foreach (NodeMap *l, m_top) {
+        for (NodeMap *l : std::as_const(m_top)) {
             const QList<Node*> &nodes = l->values();
             int row = nodes.indexOf(static_cast<Node*>(index.internalPointer()));
             if (row != -1) {
@@ -684,7 +681,7 @@ Node *TaskStatusItemModel::node(const QModelIndex &index) const
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 TaskStatusItemModel::TaskStatus TaskStatusItemModel::taskStatus(const Task *task,
@@ -712,7 +709,7 @@ TaskStatusItemModel::TaskStatus TaskStatusItemModel::taskStatus(const Task *task
 void TaskStatusItemModel::slotNodeChanged(Node *node)
 {
     debugPlan;
-    if (node == 0 || node->type() == Node::Type_Project ||
+    if (node == nullptr || node->type() == Node::Type_Project ||
         (node->type() != Node::Type_Task && node->type() != Node::Type_Milestone)) {
         return;
     }
@@ -736,7 +733,7 @@ void TaskStatusItemModel::slotNodeChanged(Node *node)
 
     if (row >= 0) {
         // task in old group, just changed values
-        emit dataChanged(createIndex(row, 0, node), createIndex(row, columnCount() - 1, node));
+        Q_EMIT dataChanged(createIndex(row, 0, node), createIndex(row, columnCount() - 1, node));
     } else {
         // task is new or changed groups
         refresh();
@@ -746,10 +743,10 @@ void TaskStatusItemModel::slotNodeChanged(Node *node)
 void TaskStatusItemModel::slotWbsDefinitionChanged()
 {
     debugPlan;
-    foreach (NodeMap *l, m_top) {
+    for (NodeMap *l : std::as_const(m_top)) {
         for (int row = 0; row < l->count(); ++row) {
             const QList<Node*> &nodes = l->values();
-            emit dataChanged(createIndex(row, NodeModel::NodeWBSCode, nodes.value(row)), createIndex(row, NodeModel::NodeWBSCode, nodes.value(row)));
+            Q_EMIT dataChanged(createIndex(row, NodeModel::NodeWBSCode, nodes.value(row)), createIndex(row, NodeModel::NodeWBSCode, nodes.value(row)));
         }
     }
 }
