@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004-2006 David Faure <faure@kde.org>
-   Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
-   Copyright (C) 2010 Jarosław Staniek <staniek@kde.org>
-   Copyright (C) 2011 Pierre Ducroquet <pinaraf@pinaraf.info>
+   SPDX-FileCopyrightText: 2004-2006 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2007 Thorsten Zachmann <zachmann@kde.org>
+   SPDX-FileCopyrightText: 2010 Jarosław Staniek <staniek@kde.org>
+   SPDX-FileCopyrightText: 2011 Pierre Ducroquet <pinaraf@pinaraf.info>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 // clazy:excludeall=qstring-arg
 #include "KoGenStyle.h"
@@ -32,10 +19,10 @@
 #include <OdfDebug.h>
 
 // Returns -1, 0 (equal) or 1
-static int compareMap(const QMap<QString, QString>& map1, const QMap<QString, QString>& map2)
+static int compareMap(const QMultiMap<QString, QString>& map1, const QMultiMap<QString, QString>& map2)
 {
-    QMap<QString, QString>::const_iterator it = map1.constBegin();
-    QMap<QString, QString>::const_iterator oit = map2.constBegin();
+    QMultiMap<QString, QString>::const_iterator it = map1.constBegin();
+    QMultiMap<QString, QString>::const_iterator oit = map2.constBegin();
     for (; it != map1.constEnd(); ++it, ++oit) {   // both maps have been checked for size already
         if (it.key() != oit.key())
             return it.key() < oit.key() ? -1 : + 1;
@@ -130,7 +117,7 @@ static const KoGenStyle::PropertyType s_propertyTypes[] = {
 };
 
 static const char* const s_propertyNames[] = {
-    0,
+    nullptr,
     "style:section-properties",
     "style:ruby-properties",
     "style:table-properties",
@@ -159,7 +146,7 @@ static KoGenStyle::PropertyType propertyTypeByElementName(const char* properties
 void KoGenStyle::writeStyleProperties(KoXmlWriter* writer, PropertyType type,
                                       const KoGenStyle* parentStyle) const
 {
-    const char* elementName = 0;
+    const char* elementName = nullptr;
     for (int i=0; i<s_propertyNamesCount; ++i) {
         if (s_propertyTypes[i] == type) {
             elementName = s_propertyNames[i];
@@ -170,17 +157,17 @@ void KoGenStyle::writeStyleProperties(KoXmlWriter* writer, PropertyType type,
     const StyleMap& mapChild = m_childProperties[type];
     if (!map.isEmpty() || !mapChild.isEmpty()) {
         writer->startElement(elementName);
-        QMap<QString, QString>::const_iterator it = map.constBegin();
-        const QMap<QString, QString>::const_iterator end = map.constEnd();
+        QMultiMap<QString, QString>::const_iterator it = map.constBegin();
+        const QMultiMap<QString, QString>::const_iterator end = map.constEnd();
         for (; it != end; ++it) {
             if (!parentStyle || parentStyle->property(it.key(), type) != it.value())
-                writer->addAttribute(it.key().toUtf8(), it.value().toUtf8());
+                writer->addAttribute(it.key().toUtf8().constData(), it.value().toUtf8());
         }
-        QMap<QString, QString>::const_iterator itChild = mapChild.constBegin();
-        const QMap<QString, QString>::const_iterator endChild = mapChild.constEnd();
+        QMultiMap<QString, QString>::const_iterator itChild = mapChild.constBegin();
+        const QMultiMap<QString, QString>::const_iterator endChild = mapChild.constEnd();
         for (; itChild != endChild; ++itChild) {
             if (!parentStyle || parentStyle->childProperty(itChild.key(), type) != itChild.value())
-                writer->addCompleteElement(itChild.value().toUtf8());
+                writer->addCompleteElement(itChild.value().toUtf8().constData());
         }
         writer->endElement();
     }
@@ -190,7 +177,7 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
 {
     //debugOdf <<"writing out style" << name <<" display-name=" << m_attributes["style:display-name"] <<" family=" << m_familyName;
     writer->startElement(elementName);
-    const KoGenStyle* parentStyle = 0;
+    const KoGenStyle* parentStyle = nullptr;
     if (!m_defaultStyle) {
         if (!drawElement)
             writer->addAttribute("style:name", name);
@@ -215,7 +202,7 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
     }
     if (!m_familyName.isEmpty())
         const_cast<KoGenStyle *>(this)->
-        addAttribute("style:family", QString::fromLatin1(m_familyName));
+        addAttribute(QStringLiteral("style:family"), QString::fromLatin1(m_familyName));
     else {
         if (qstrcmp(elementName, "style:style") == 0)
             warnOdf << "User style " << name << " is without family - invalid. m_type=" << m_type;
@@ -234,14 +221,14 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
     // We only look at the direct parent style because we assume
     // that styles are fully specified, i.e. the inheritance is
     // only in the final file, not in the caller's code.
-    QMap<QString, QString>::const_iterator it = m_attributes.constBegin();
+    QMultiMap<QString, QString>::const_iterator it = m_attributes.constBegin();
     for (; it != m_attributes.constEnd(); ++it) {
         bool writeit = true;
-        if (parentStyle && it.key() != "style:family"  // always write the family out
+        if (parentStyle && it.key() != QStringLiteral("style:family")  // always write the family out
                 && parentStyle->attribute(it.key()) == it.value())
             writeit = false;
         if (writeit)
-            writer->addAttribute(it.key().toUtf8(), it.value().toUtf8());
+            writer->addAttribute(it.key().toUtf8().constData(), it.value().toUtf8());
     }
     bool createPropertiesTag = propertiesElementName && propertiesElementName[0] != '\0';
     KoGenStyle::PropertyType i = KoGenStyle::DefaultType;
@@ -256,7 +243,7 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
         it = m_properties[i].constBegin();
         for (; it != m_properties[i].constEnd(); ++it) {
             if (!parentStyle || parentStyle->property(it.key(), i) != it.value())
-                writer->addAttribute(it.key().toUtf8(), it.value().toUtf8());
+                writer->addAttribute(it.key().toUtf8().constData(), it.value().toUtf8());
         }
         //write the explicitly-defined properties that are the same type as the default,
         //but only if defaultPropertyType is Text, Paragraph, or GraphicType
@@ -264,14 +251,14 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
             it = m_properties[defaultPropertyType].constBegin();
             for (; it != m_properties[defaultPropertyType].constEnd(); ++it) {
                 if (!parentStyle || parentStyle->property(it .key(), defaultPropertyType) != it.value())
-                    writer->addAttribute(it.key().toUtf8(), it.value().toUtf8());
+                    writer->addAttribute(it.key().toUtf8().constData(), it.value().toUtf8());
             }
         }
         //write child elements of the properties elements
         it = m_childProperties[defaultPropertyType].constBegin();
         for (; it != m_childProperties[defaultPropertyType].constEnd(); ++it) {
             if (!parentStyle || parentStyle->childProperty(it.key(), defaultPropertyType) != it.value()) {
-                writer->addCompleteElement(it.value().toUtf8());
+                writer->addCompleteElement(it.value().toUtf8().constData());
             }
         }
         if (createPropertiesTag)
@@ -292,7 +279,7 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
     it = m_properties[i].constBegin();
     for (; it != m_properties[i].constEnd(); ++it) {
         if (!parentStyle || parentStyle->property(it.key(), i) != it.value()) {
-            writer->addCompleteElement(it.value().toUtf8());
+            writer->addCompleteElement(it.value().toUtf8().constData());
         }
     }
 
@@ -303,9 +290,9 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
             writeit = false;
         if (writeit) {
             writer->startElement("style:map");
-            QMap<QString, QString>::const_iterator it = m_maps[i].constBegin();
+            QMultiMap<QString, QString>::const_iterator it = m_maps[i].constBegin();
             for (; it != m_maps[i].constEnd(); ++it) {
-                writer->addAttribute(it.key().toUtf8(), it.value().toUtf8());
+                writer->addAttribute(it.key().toUtf8().constData(), it.value().toUtf8());
             }
             writer->endElement(); // style:map
         }
@@ -314,6 +301,11 @@ void KoGenStyle::writeStyle(KoXmlWriter* writer, const KoGenStyles& styles, cons
         writer->endElement();
 }
 
+void KoGenStyle::addPropertyPt(const char *propName, qreal propValue, PropertyType type)
+{
+    addPropertyPt(QLatin1String(propName), propValue, type);
+}
+
 void KoGenStyle::addPropertyPt(const QString& propName, qreal propValue, PropertyType type)
 {
     if (type == DefaultType) {
@@ -321,7 +313,7 @@ void KoGenStyle::addPropertyPt(const QString& propName, qreal propValue, Propert
     }
     QString str;
     str.setNum(propValue, 'f', DBL_DIG);
-    str += "pt";
+    str += QStringLiteral("pt");
     m_properties[type].insert(propName, str);
 }
 
@@ -335,7 +327,7 @@ void KoGenStyle::addPropertyLength(const QString& propName, const QTextLength &p
     } else {
         QString str;
         str.setNum((int) propValue.rawValue());
-        str += '%';
+        str += QLatin1Char('%');
         m_properties[type].insert(propName, str);
     }
 }
@@ -344,10 +336,20 @@ void KoGenStyle::addAttributePt(const QString& attrName, qreal attrValue)
 {
     QString str;
     str.setNum(attrValue, 'f', DBL_DIG);
-    str += "pt";
+    str += QStringLiteral("pt");
     m_attributes.insert(attrName, str);
 }
 
+void KoGenStyle::addAttributePt(const char *attrName, qreal attrValue)
+{
+    addAttributePt(QLatin1String(attrName), attrValue);
+}
+
+void KoGenStyle::addAttributePercent(const char *attrName, qreal value)
+{
+    addAttributePercent(QLatin1String(attrName), value);
+}
+
 void KoGenStyle::addAttributePercent(const QString &attrName, qreal value)
 {
     QByteArray str;
@@ -356,6 +358,11 @@ void KoGenStyle::addAttributePercent(const QString &attrName, qreal value)
     addAttribute(attrName, str.data());
 }
 
+void KoGenStyle::addAttributePercent(const char *attrName, int value)
+{
+    addAttributePercent(QLatin1String(attrName), value);
+}
+
 void KoGenStyle::addAttributePercent(const QString &attrName, int value)
 {
     QByteArray str;
@@ -364,7 +371,7 @@ void KoGenStyle::addAttributePercent(const QString &attrName, int value)
     addAttribute(attrName, str.data());
 }
 
-void KoGenStyle::addStyleMap(const QMap<QString, QString>& styleMap)
+void KoGenStyle::addStyleMap(const QMultiMap<QString, QString>& styleMap)
 {
     // check, if already present
     for (int i = 0 ; i < m_maps.count() ; ++i) {
@@ -383,37 +390,37 @@ void KoGenStyle::printDebug() const
 {
     int i = DefaultType;
     debugOdf << m_properties[i].count() << " properties.";
-    for (QMap<QString, QString>::ConstIterator it = m_properties[i].constBegin(); it != m_properties[i].constEnd(); ++it) {
+    for (QMultiMap<QString, QString>::ConstIterator it = m_properties[i].constBegin(); it != m_properties[i].constEnd(); ++it) {
         debugOdf << "" << it.key() << " =" << it.value();
     }
     i = TextType;
     debugOdf << m_properties[i].count() << " text properties.";
-    for (QMap<QString, QString>::ConstIterator it = m_properties[i].constBegin(); it != m_properties[i].constEnd(); ++it) {
+    for (QMultiMap<QString, QString>::ConstIterator it = m_properties[i].constBegin(); it != m_properties[i].constEnd(); ++it) {
         debugOdf << "" << it.key() << " =" << it.value();
     }
     i = ParagraphType;
     debugOdf << m_properties[i].count() << " paragraph properties.";
-    for (QMap<QString, QString>::ConstIterator it = m_properties[i].constBegin(); it != m_properties[i].constEnd(); ++it) {
+    for (QMultiMap<QString, QString>::ConstIterator it = m_properties[i].constBegin(); it != m_properties[i].constEnd(); ++it) {
         debugOdf << "" << it.key() << " =" << it.value();
     }
     i = TextType;
     debugOdf << m_childProperties[i].count() << " text child elements.";
-    for (QMap<QString, QString>::ConstIterator it = m_childProperties[i].constBegin(); it != m_childProperties[i].constEnd(); ++it) {
+    for (QMultiMap<QString, QString>::ConstIterator it = m_childProperties[i].constBegin(); it != m_childProperties[i].constEnd(); ++it) {
         debugOdf << "" << it.key() << " =" << it.value();
     }
     i = ParagraphType;
     debugOdf << m_childProperties[i].count() << " paragraph child elements.";
-    for (QMap<QString, QString>::ConstIterator it = m_childProperties[i].constBegin(); it != m_childProperties[i].constEnd(); ++it) {
+    for (QMultiMap<QString, QString>::ConstIterator it = m_childProperties[i].constBegin(); it != m_childProperties[i].constEnd(); ++it) {
         debugOdf << "" << it.key() << " =" << it.value();
     }
     debugOdf << m_attributes.count() << " attributes.";
-    for (QMap<QString, QString>::ConstIterator it = m_attributes.constBegin(); it != m_attributes.constEnd(); ++it) {
+    for (QMultiMap<QString, QString>::ConstIterator it = m_attributes.constBegin(); it != m_attributes.constEnd(); ++it) {
         debugOdf << "" << it.key() << " =" << it.value();
     }
     debugOdf << m_maps.count() << " maps.";
     for (int i = 0; i < m_maps.count(); ++i) {
         debugOdf << "map" << i << ":";
-        for (QMap<QString, QString>::ConstIterator it = m_maps[i].constBegin(); it != m_maps[i].constEnd(); ++it) {
+        for (QMultiMap<QString, QString>::ConstIterator it = m_maps[i].constBegin(); it != m_maps[i].constEnd(); ++it) {
             debugOdf << "" << it.key() << " =" << it.value();
         }
     }
@@ -515,8 +522,8 @@ void KoGenStyle::copyPropertiesFromStyle(const KoGenStyle &sourceStyle, KoGenSty
 
     const StyleMap& map = sourceStyle.m_properties[type];
     if (!map.isEmpty()) {
-        QMap<QString, QString>::const_iterator it = map.constBegin();
-        const QMap<QString, QString>::const_iterator end = map.constEnd();
+        QMultiMap<QString, QString>::const_iterator it = map.constBegin();
+        const QMultiMap<QString, QString>::const_iterator end = map.constEnd();
         for (; it != end; ++it) {
             targetStyle.addProperty(it.key(), it.value(), type);
         }
