@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2017 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -67,9 +54,9 @@ void TasksGeneralPanel::setStartValues(Task *task) {
     m_calendars.clear();
     calendarCombo->addItem(i18n("None"));
     m_calendars.insert(0, 0);
-    QList<Calendar*> list = m_project.allCalendars();
+    const QList<Calendar*> list = m_project.allCalendars();
     int i=1;
-    foreach (Calendar *c, list) {
+    for (Calendar *c : list) {
         calendarCombo->insertItem(i, c->name());
         m_calendars.insert(i, c);
         if (c == task->estimate()->calendar()) {
@@ -249,7 +236,7 @@ void TasksGeneralPanelImpl::setSchedulingType(int type)
 {
     enableDateTime(type);
     scheduleType->setCurrentIndex(type);
-    emit schedulingTypeChanged(type);
+    Q_EMIT schedulingTypeChanged(type);
 }
 
 int TasksGeneralPanelImpl::schedulingType() const
@@ -264,7 +251,7 @@ void TasksGeneralPanelImpl::changeLeader()
     if (dlg->exec() && dlg) {
         QStringList names;
         const Akonadi::EmailAddressSelection::List selections = dlg->selectedAddresses();
-        foreach (const Akonadi::EmailAddressSelection &selection, selections) {
+        for (const Akonadi::EmailAddressSelection &selection : selections) {
             QString s = selection.name();
             if (! selection.email().isEmpty()) {
                 if (! selection.name().isEmpty()) {
@@ -384,8 +371,8 @@ void TasksGeneralPanelImpl::setEstimateType(int type)
 
 void TasksGeneralPanelImpl::checkAllFieldsFilled()
 {
-    emit changed();
-    emit obligatedFieldsFilled(true); // do not block save even if name is not filled
+    Q_EMIT changed();
+    Q_EMIT obligatedFieldsFilled(true); // do not block save even if name is not filled
 }
 
 
