@@ -1,27 +1,15 @@
 /* This file is part of the KDE project
- *  Copyright (C) 2019 Dag Andersen <danders@get2net.dk>
- *  Copyright (C) 2006-2011, 2012 Dag Andersen <danders@get2net.dk>
+ *  SPDX-FileCopyrightText: 2019 Dag Andersen <dag.andersen@kdemail.net>
+ *  SPDX-FileCopyrightText: 2006-2011, 2012 Dag Andersen <dag.andersen@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
 #include "kptscheduleeditor.h"
 
 #include "kptcommand.h"
+#include "commands/ModifyScheduleManagerOwnerCmd.h"
 #include "kptcalendar.h"
 #include "kptduration.h"
 #include "kptnode.h"
@@ -32,8 +20,10 @@
 #include "kptpertresult.h"
 #include "kptitemviewsettup.h"
 #include "kptrecalculatedialog.h"
-#include "Help.h"
 #include "kptdebug.h"
+#include "kpttaskdialog.h"
+#include "kptsummarytaskdialog.h"
+#include "kptresourcedialog.h"
 
 #include <KoDocument.h>
 #include <KoIcon.h>
@@ -48,9 +38,9 @@
 #include <QMenu>
 
 #include <KLocalizedString>
-#include <kactioncollection.h>
-
-#include <ktoggleaction.h>
+#include <KMessageBox>
+#include <KActionCollection>
+#include <KToggleAction>
 
 
 namespace KPlato
@@ -74,19 +64,20 @@ ScheduleTreeView::ScheduleTreeView(QWidget *parent)
 void ScheduleTreeView::selectionChanged(const QItemSelection &sel, const QItemSelection &desel)
 {
     //debugPlan<<sel.indexes().count();
-    foreach(const QModelIndex &i, selectionModel()->selectedIndexes()) {
+    const auto lst = selectionModel()->selectedIndexes();
+    for (const QModelIndex &i : lst) {
         Q_UNUSED(i);
         //debugPlan<<i.row()<<","<<i.column();
     }
     QTreeView::selectionChanged(sel, desel);
-    emit selectionChanged(selectionModel()->selectedIndexes());
+    Q_EMIT selectedIndexesChanged(selectionModel()->selectedIndexes());
 }
 
 void ScheduleTreeView::currentChanged(const QModelIndex & current, const QModelIndex & previous)
 {
     //debugPlan<<current.row()<<","<<current.column();
     QTreeView::currentChanged(current, previous);
-    emit currentChanged(current);
+    Q_EMIT currentIndexChanged(current);
     // possible bug in qt: in QAbstractItemView::SingleSelection you can select multiple items/rows
     selectionModel()->select(current, QItemSelectionModel::Rows | QItemSelectionModel::ClearAndSelect);
 }
@@ -110,7 +101,7 @@ QModelIndexList ScheduleTreeView::selectedRows() const
 
 ScheduleManager *ScheduleTreeView::selectedManager() const
 {
-    ScheduleManager *sm = 0;
+    ScheduleManager *sm = nullptr;
     QModelIndexList lst = selectedRows();
     if (lst.count() == 1) {
         sm = model()->manager(lst.first());
@@ -122,17 +113,12 @@ ScheduleManager *ScheduleTreeView::selectedManager() const
 ScheduleEditor::ScheduleEditor(KoPart *part, KoDocument *doc, QWidget *parent)
     : ViewBase(part, doc, parent)
 {
-    if (doc && doc->isReadWrite()) {
-        setXMLFile("ScheduleEditorUi.rc");
-    } else {
-        setXMLFile("ScheduleEditorUi_readonly.rc");
-    }
+    setXMLFile(QStringLiteral("ScheduleEditorUi.rc"));
 
     setupGui();
-    slotEnableActions();
 
     QVBoxLayout * l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_schedulingRange = new SchedulingRange(doc, this);
     l->addWidget(m_schedulingRange);
     m_view = new ScheduleTreeView(this);
@@ -167,9 +153,9 @@ ScheduleEditor::ScheduleEditor(KoPart *part, KoDocument *doc, QWidget *parent)
 
     connect(model(), &ItemModelBase::executeCommand, doc, &KoDocument::addCommand);
 
-    connect(m_view, SIGNAL(currentChanged(QModelIndex)), this, SLOT(slotCurrentChanged(QModelIndex)));
+    connect(m_view, &ScheduleTreeView::currentIndexChanged, this, &ScheduleEditor::slotCurrentChanged);
 
-    connect(m_view, SIGNAL(selectionChanged(QModelIndexList)), this, SLOT(slotSelectionChanged(QModelIndexList)));
+    connect(m_view, &ScheduleTreeView::selectedIndexesChanged, this, &ScheduleEditor::slotSelectionChanged);
 
     connect(model(), &QAbstractItemModel::dataChanged, this, &ScheduleEditor::updateActionsEnabled);
 
@@ -177,7 +163,9 @@ ScheduleEditor::ScheduleEditor(KoPart *part, KoDocument *doc, QWidget *parent)
 
     connect(m_view, &TreeViewBase::headerContextMenuRequested, this, &ViewBase::slotHeaderContextMenuRequested);
 
-    Help::add(this,
+    slotEnableActions();
+
+    setWhatsThis(
         xi18nc("@info:whatsthis", 
                "<title>Schedule Editor</title>"
                "<para>"
@@ -191,7 +179,7 @@ ScheduleEditor::ScheduleEditor(KoPart *part, KoDocument *doc, QWidget *parent)
                " in order to reschedule only tasks that are not yet finished."
                " Rescheduling will then use e.g. actual start and remaining effort for the tasks."
                "<nl/><link url='%1'>More...</link>"
-               "</para>", Help::page("Schedules_Editor")));
+               "</para>", QStringLiteral("plan:schedules-editor")));
 }
 
 void ScheduleEditor::draw(Project &project)
@@ -218,13 +206,18 @@ void ScheduleEditor::slotContextMenuRequested(const QModelIndex &index, const QP
     debugPlan<<index.row()<<","<<index.column()<<":"<<pos;
     QString name;
     m_view->setContextMenuIndex(index);
+    if (index.column() == ScheduleModel::ScheduleState) {
+        auto sm = m_view->selectedManager();
+        if (sm && sm->owner() != ScheduleManager::OwnerPlan) {
+            name = QStringLiteral("scheduleeditor_status_popup");
+        }
+    }
     if (name.isEmpty()) {
         slotHeaderContextMenuRequested(pos);
-        m_view->setContextMenuIndex(QModelIndex());
-        return;
+    } else {
+        openPopupMenu(name, pos);
     }
     debugPlan<<name;
-    emit requestPopupMenu(name, pos);
     m_view->setContextMenuIndex(QModelIndex());
 }
 
@@ -240,9 +233,9 @@ void ScheduleEditor::slotSelectionChanged(const QModelIndexList &/*list*/)
     QModelIndexList lst = m_view->selectedRows(); // gets column 0 in each row (should be 1 or 0 rows)
     if (lst.count() == 1) {
         ScheduleManager *sm = m_view->model()->manager(lst.first());
-        emit scheduleSelectionChanged(sm);
+        Q_EMIT scheduleSelectionChanged(sm);
     } else {
-        emit scheduleSelectionChanged(0);
+        Q_EMIT scheduleSelectionChanged(nullptr);
     }
     slotEnableActions();
 
@@ -306,34 +299,38 @@ void ScheduleEditor::slotEnableActions()
 void ScheduleEditor::setupGui()
 {
     actionAddSchedule  = new QAction(koIcon("view-time-schedule-insert"), i18n("Add Schedule"), this);
-    actionCollection()->setDefaultShortcut(actionAddSchedule, Qt::CTRL + Qt::Key_I);
-    actionCollection()->addAction("add_schedule", actionAddSchedule);
+    actionCollection()->setDefaultShortcut(actionAddSchedule, Qt::CTRL | Qt::Key_I);
+    actionCollection()->addAction(QStringLiteral("add_schedule"), actionAddSchedule);
     connect(actionAddSchedule, &QAction::triggered, this, &ScheduleEditor::slotAddSchedule);
 
     actionAddSubSchedule  = new QAction(koIcon("view-time-schedule-child-insert"), i18n("Add Sub-schedule"), this);
-    actionCollection()->setDefaultShortcut(actionAddSubSchedule, Qt::CTRL + Qt::SHIFT + Qt::Key_I);
-    actionCollection()->addAction("add_subschedule", actionAddSubSchedule);
+    actionCollection()->setDefaultShortcut(actionAddSubSchedule, Qt::CTRL | Qt::SHIFT | Qt::Key_I);
+    actionCollection()->addAction(QStringLiteral("add_subschedule"), actionAddSubSchedule);
     connect(actionAddSubSchedule, &QAction::triggered, this, &ScheduleEditor::slotAddSubSchedule);
 
     actionDeleteSelection  = new QAction(koIcon("edit-delete"), xi18nc("@action", "Delete"), this);
     actionCollection()->setDefaultShortcut(actionDeleteSelection, Qt::Key_Delete);
-    actionCollection()->addAction("delete_selection", actionDeleteSelection);
+    actionCollection()->addAction(QStringLiteral("delete_selection"), actionDeleteSelection);
     connect(actionDeleteSelection, &QAction::triggered, this, &ScheduleEditor::slotDeleteSelection);
 
     actionCalculateSchedule  = new QAction(koIcon("view-time-schedule-calculus"), i18n("Calculate"), this);
 //    actionCollection()->setDefaultShortcut(actionCalculateSchedule, Qt::CTRL + Qt::Key_C);
-    actionCollection()->addAction("calculate_schedule", actionCalculateSchedule);
+    actionCollection()->addAction(QStringLiteral("calculate_schedule"), actionCalculateSchedule);
     connect(actionCalculateSchedule, &QAction::triggered, this, &ScheduleEditor::slotCalculateSchedule);
 
     actionBaselineSchedule  = new QAction(koIcon("view-time-schedule-baselined-add"), i18n("Baseline"), this);
 //    actionCollection()->setDefaultShortcut(actionBaselineSchedule, Qt::CTRL + Qt::Key_B);
-    actionCollection()->addAction("schedule_baseline", actionBaselineSchedule);
+    actionCollection()->addAction(QStringLiteral("schedule_baseline"), actionBaselineSchedule);
     connect(actionBaselineSchedule, &QAction::triggered, this, &ScheduleEditor::slotBaselineSchedule);
 
     actionMoveLeft  = new QAction(koIcon("go-first"), xi18nc("@action", "Detach"), this);
-    actionCollection()->addAction("schedule_move_left", actionMoveLeft);
+    actionCollection()->addAction(QStringLiteral("schedule_move_left"), actionMoveLeft);
     connect(actionMoveLeft, &QAction::triggered, this, &ScheduleEditor::slotMoveLeft);
 
+    auto a = new QAction(i18nc("@action", "Claim Schedule"));
+    actionCollection()->addAction(QStringLiteral("claim_schedule"), a);
+    connect(a, &QAction::triggered, this, &ScheduleEditor::slotClaimSchedule);
+
     // Add the context menu actions for the view options
     createOptionActions(ViewBase::OptionExpand | ViewBase::OptionCollapse | ViewBase::OptionViewConfig);
 }
@@ -359,10 +356,28 @@ void ScheduleEditor::slotCalculateSchedule()
 {
     //debugPlan;
     ScheduleManager *sm = m_view->selectedManager();
-    if (sm == 0) {
+    if (project() == nullptr || sm == nullptr) {
         return;
     }
-    if (sm->parentManager() || (sm->isScheduled() && project()->isStarted())) {
+    auto parentManager = sm->parentManager();
+    if (parentManager && !parentManager->isScheduled()) {
+        KMessageBox::information(this,
+                                i18n("This schedule cannot be calculated.\nThe parent schedule must be calculated first"),
+                                i18n("Project Scheduling"));
+        return;
+    }
+    if (!parentManager && sm->isScheduled() && project()->isStarted()) {
+        KMessageBox::ButtonCode reply = KMessageBox::questionTwoActions (this,
+                                        i18n("The project has been started.\nDo you really want to calculate this schedule?"),
+                                        i18n("Project Scheduling"),
+                                        KStandardGuiItem::cont(),
+                                        KStandardGuiItem::cancel());
+
+        if (reply == KMessageBox::SecondaryAction) {
+            return;
+        }
+    }
+    if (parentManager && parentManager->isScheduled()) {
         RecalculateDialog dlg;
         if (dlg.exec() == QDialog::Rejected) {
             return;
@@ -370,7 +385,8 @@ void ScheduleEditor::slotCalculateSchedule()
         sm->setRecalculate(true);
         sm->setRecalculateFrom(DateTime(dlg.dateTime()));
     }
-    emit calculateSchedule(m_view->project(), sm);
+    CalculateScheduleCmd *cmd =  new CalculateScheduleCmd(*project(), sm, kundo2_i18nc("@info:status 1=schedule name", "Calculate %1", sm->name()));
+    koDocument()->addCommand(cmd);
 }
 
 void ScheduleEditor::slotAddSchedule()
@@ -386,7 +402,7 @@ void ScheduleEditor::slotAddSchedule()
     }
     if (sm && sm->parentManager()) {
         sm = sm->parentManager();
-        ScheduleManager *m = m_view->project()->createScheduleManager(sm->name() + QString(".%1").arg(sm->children().count() + 1));
+        ScheduleManager *m = m_view->project()->createScheduleManager(sm->name() + QStringLiteral(".%1").arg(sm->children().count() + 1));
         part()->addCommand(new AddScheduleManagerCmd(sm, m, idx, kundo2_i18n("Create sub-schedule")));
         QModelIndex idx = model()->index(m);
         if (idx.isValid()) {
@@ -419,7 +435,7 @@ void ScheduleEditor::slotAddSubSchedule()
         if (row >= 0) {
             ++row;
         }
-        ScheduleManager *m = m_view->project()->createScheduleManager(sm->name() + QString(".%1").arg(sm->children().count() + 1));
+        ScheduleManager *m = m_view->project()->createScheduleManager(sm->name() + QStringLiteral(".%1").arg(sm->children().count() + 1));
         part()->addCommand(new AddScheduleManagerCmd(sm, m, row, kundo2_i18n("Create sub-schedule")));
         m_view->expand(model()->index(sm));
         QModelIndex idx = model()->index(m);
@@ -436,9 +452,29 @@ void ScheduleEditor::slotBaselineSchedule()
 {
     //debugPlan;
     ScheduleManager *sm = m_view->selectedManager();
-    if (sm) {
-        emit baselineSchedule(m_view->project(), sm);
+    if (project() == nullptr || sm == nullptr) {
+        return;
     }
+    if (!sm->isBaselined() && project()->isBaselined()) {
+        KMessageBox::error(this, i18n("Cannot baseline. The project is already baselined."));
+        return;
+    }
+    MacroCommand *cmd = nullptr;
+    if (sm->isBaselined()) {
+        KMessageBox::ButtonCode res = KMessageBox::warningContinueCancel(this, i18n("This schedule is baselined. Do you want to remove the baseline?"));
+        if (res == KMessageBox::Cancel) {
+            return;
+        }
+        cmd = new MacroCommand(kundo2_i18n("Reset baseline %1", sm->name()));
+        cmd->addCommand(new ResetBaselineScheduleCmd(*sm));
+    } else {
+        cmd = new MacroCommand(kundo2_i18n("Baseline %1", sm->name()));
+        if (sm->schedulingMode() == ScheduleManager::AutoMode) {
+            cmd->addCommand(new ModifyScheduleManagerSchedulingModeCmd(*sm, ScheduleManager::ManualMode));
+        }
+        cmd->addCommand(new BaselineScheduleCmd(*sm, kundo2_i18n("Baseline %1", sm->name())));
+    }
+    koDocument()->addCommand(cmd);
 }
 
 void ScheduleEditor::slotDeleteSelection()
@@ -446,7 +482,8 @@ void ScheduleEditor::slotDeleteSelection()
     //debugPlan;
     ScheduleManager *sm = m_view->selectedManager();
     if (sm) {
-        emit deleteScheduleManager(m_view->project(), sm);
+        DeleteScheduleManagerCmd *cmd =  new DeleteScheduleManagerCmd(*project(), sm, kundo2_i18n("Delete schedule %1", sm->name()));
+        koDocument()->addCommand(cmd);
     }
 }
 
@@ -455,13 +492,23 @@ void ScheduleEditor::slotMoveLeft()
     ScheduleManager *sm = m_view->selectedManager();
     if (sm) {
         int index = -1;
-        for (ScheduleManager *m = sm; m != 0; m = m->parentManager()) {
-            if (m->parentManager() == 0) {
+        for (ScheduleManager *m = sm; m != nullptr; m = m->parentManager()) {
+            if (m->parentManager() == nullptr) {
                  index = m->project().indexOf(m) + 1;
             }
         }
         debugPlan<<sm->name()<<index;
-        emit moveScheduleManager(sm, 0, index);
+        MoveScheduleManagerCmd *cmd =  new MoveScheduleManagerCmd(sm, nullptr, index, kundo2_i18n("Move schedule %1", sm->name()));
+        koDocument()->addCommand(cmd);
+    }
+}
+
+void ScheduleEditor::slotClaimSchedule()
+{
+    ScheduleManager *sm = m_view->selectedManager();
+    if (sm) {
+        auto cmd = new ModifyScheduleManagerOwnerCmd(sm, ScheduleManager::OwnerPlan, kundo2_i18n("Claim schedule %1", sm->name()));
+        koDocument()->addCommand(cmd);
     }
 }
 
@@ -491,7 +538,7 @@ ScheduleLogTreeView::ScheduleLogTreeView(QWidget *parent)
     m_model = new QSortFilterProxyModel(this);
     m_model->setFilterRole(Qt::UserRole+1);
     m_model->setFilterKeyColumn (2); // severity
-    m_model->setFilterWildcard("[^0]"); // Filter out Debug
+    m_model->setFilterWildcard(QStringLiteral("[^0]")); // Filter out Debug
 
     m_model->setSourceModel(new ScheduleLogItemModel(this));
     setModel(m_model);
@@ -512,20 +559,20 @@ void ScheduleLogTreeView::setFilterWildcard(const QString &filter)
     m_model->setFilterWildcard(filter);
 }
 
-QRegExp ScheduleLogTreeView::filterRegExp() const
+QRegularExpression ScheduleLogTreeView::filterRegExp() const
 {
-    return m_model->filterRegExp();
+    return m_model->filterRegularExpression();
 }
 
 void ScheduleLogTreeView::slotShowDebug(bool on)
 {
-    on ? setFilterWildcard(QString()) : setFilterWildcard("[^0]");
+    on ? setFilterWildcard(QString()) : setFilterWildcard(QStringLiteral("[^0]"));
 }
 
 void ScheduleLogTreeView::contextMenuEvent (QContextMenuEvent *e)
 {
     debugPlan<<indexAt(e->pos())<<" at"<<e->pos();
-    emit contextMenuRequested(indexAt(e->pos()), e->globalPos());
+    Q_EMIT contextMenuRequested(indexAt(e->pos()), e->globalPos());
 }
 
 void ScheduleLogTreeView::headerContextMenuRequested(const QPoint &pos)
@@ -540,29 +587,29 @@ void ScheduleLogTreeView::headerContextMenuRequested(const QPoint &pos)
 void ScheduleLogTreeView::selectionChanged(const QItemSelection &sel, const QItemSelection &desel)
 {
     //debugPlan<<sel.indexes().count();
-    foreach(const QModelIndex &i, selectionModel()->selectedIndexes()) {
+    const auto lst = selectionModel()->selectedIndexes();
+    for (const QModelIndex &i : lst) {
         Q_UNUSED(i);
         //debugPlan<<i.row()<<","<<i.column();
     }
     QTreeView::selectionChanged(sel, desel);
-    emit selectionChanged(selectionModel()->selectedIndexes());
+    Q_EMIT selectedIndexesChanged(selectionModel()->selectedIndexes());
 }
 
 void ScheduleLogTreeView::currentChanged(const QModelIndex & current, const QModelIndex & previous)
 {
     //debugPlan<<current.row()<<","<<current.column();
     QTreeView::currentChanged(current, previous);
-    emit currentChanged(current);
+    Q_EMIT currentIndexChanged(current);
 //    selectionModel()->select(current, QItemSelectionModel::Rows | QItemSelectionModel::ClearAndSelect);
 }
 
 void ScheduleLogTreeView::slotEditCopy()
 {
     QStringList lst;
-//    int row = 0;
-    QString s;
     QHeaderView *h = header();
-    foreach(const QModelIndex &i, selectionModel()->selectedRows()) {
+    const auto indexes = selectionModel()->selectedIndexes();
+    for (const QModelIndex &i : indexes) {
         QString s;
         for (int section = 0; section < h->count(); ++section) {
             QModelIndex idx = model()->index(i.row(), h->logicalIndex(section));
@@ -570,16 +617,16 @@ void ScheduleLogTreeView::slotEditCopy()
                 continue;
             }
             if (! s.isEmpty()) {
-                s += ' ';
+                s += QLatin1Char(' ');
             }
-            s = QString("%1%2").arg(s).arg(idx.data().toString(), -10);
+            s = QStringLiteral("%1%2").arg(s).arg(idx.data().toString(), -10);
         }
         if (! s.isEmpty()) {
             lst << s;
         }
     }
     if (! lst.isEmpty()) {
-        QApplication::clipboard()->setText(lst.join("\n"));
+        QApplication::clipboard()->setText(lst.join(QStringLiteral("\n")));
     }
 }
 
@@ -588,7 +635,7 @@ ScheduleLogView::ScheduleLogView(KoPart *part, KoDocument *doc, QWidget *parent)
     : ViewBase(part, doc, parent)
 {
     setupGui();
-    slotEnableActions(0);
+    slotEnableActions(nullptr);
 
     QVBoxLayout * l = new QVBoxLayout(this);
     m_view = new ScheduleLogTreeView(this);
@@ -596,9 +643,9 @@ ScheduleLogView::ScheduleLogView(KoPart *part, KoDocument *doc, QWidget *parent)
 //    m_view->setEditTriggers(m_view->editTriggers() | QAbstractItemView::EditKeyPressed);
 
 
-    connect(m_view, SIGNAL(currentChanged(QModelIndex)), this, SLOT(slotCurrentChanged(QModelIndex)));
+    connect(m_view, &ScheduleLogTreeView::currentIndexChanged, this, &ScheduleLogView::slotCurrentChanged);
 
-    connect(m_view, SIGNAL(selectionChanged(QModelIndexList)), this, SLOT(slotSelectionChanged(QModelIndexList)));
+    connect(m_view, &ScheduleLogTreeView::selectedIndexesChanged, this, &ScheduleLogView::slotSelectionChanged);
 
     connect(baseModel(), &QAbstractItemModel::dataChanged, this, &ScheduleLogView::updateActionsEnabled);
 
@@ -629,17 +676,17 @@ void ScheduleLogView::slotEdit()
 {
     QString id = sender()->property("p_identity").toString();
     if (id.isEmpty()) {
-        emit editNode(project());
+        Q_EMIT editNode(project());
         return;
     }
     Node *n = project()->findNode(id);
     if (n) {
-        emit editNode(n);
+        Q_EMIT editNode(n);
         return;
     }
     Resource *r = project()->findResource(id);
     if (r) {
-        emit editResource(r);
+        Q_EMIT editResource(r);
         return;
     }
     warnPlan<<"No object";
@@ -650,18 +697,17 @@ void ScheduleLogView::slotContextMenuRequested(const QModelIndex &index, const Q
     if (! isReadWrite() || ! index.isValid()) {
         return;
     }
-    QMenu *m = new QMenu(this);
+    QScopedPointer<QMenu> m(new QMenu(this));
     QString id = index.data(ScheduleLogItemModel::IdentityRole).toString();
     if (id.isEmpty()) {
         return;
     }
-    QAction *a = new QAction(koIcon("document-edit"), i18n("Edit..."), m);
+    QAction *a = new QAction(koIcon("document-edit"), i18n("Edit..."), m.get());
     a->setProperty("p_identity", id);
     m->addAction(a);
     connect(a, &QAction::triggered, this, &ScheduleLogView::slotEdit);
     m->addSeparator();
     m->exec(pos);
-    delete m;
 }
 
 void ScheduleLogView::slotScheduleSelectionChanged(ScheduleManager *sm)
@@ -731,28 +777,34 @@ ScheduleHandlerView::ScheduleHandlerView(KoPart *part, KoDocument *doc, QWidget
 {
     debugPlan<<"---------------- Create ScheduleHandlerView ------------------";
     m_scheduleEditor = new ScheduleEditor(part, doc, this);
-    m_scheduleEditor->setObjectName("ScheduleEditor");
+    m_scheduleEditor->setObjectName(QStringLiteral("ScheduleEditor"));
     addView(m_scheduleEditor);
     insertChildClient(m_scheduleEditor);
 
     QTabWidget *tab = addTabWidget();
 
     PertResult *p = new PertResult(part, doc, tab);
-    p->setObjectName("PertResult");
+    p->setObjectName(QStringLiteral("PertResult"));
     addView(p, tab, i18n("Result"));
+
     connect(m_scheduleEditor, &ScheduleEditor::scheduleSelectionChanged, p, &PertResult::slotScheduleSelectionChanged);
 
     PertCpmView *c = new PertCpmView(part, doc, tab);
-    c->setObjectName("PertCpmView");
+    c->setObjectName(QStringLiteral("PertCpmView"));
     addView(c, tab, i18n("Critical Path"));
     connect(m_scheduleEditor, &ScheduleEditor::scheduleSelectionChanged, c, &PertCpmView::slotScheduleSelectionChanged);
 
     ScheduleLogView *v = new ScheduleLogView(part, doc, tab);
-    v->setObjectName("ScheduleLogView");
+    v->setObjectName(QStringLiteral("ScheduleLogView"));
     addView(v, tab, i18n("Scheduling Log"));
     connect(m_scheduleEditor, SIGNAL(scheduleSelectionChanged(KPlato::ScheduleManager*)), v, SLOT(slotScheduleSelectionChanged(KPlato::ScheduleManager*)));
-    connect(v, &ScheduleLogView::editNode, this, &ScheduleHandlerView::editNode);
-    connect(v, &ScheduleLogView::editResource, this, &ScheduleHandlerView::editResource);
+    connect(v, &ScheduleLogView::editNode, this, &ScheduleHandlerView::slotOpenNode);
+    connect(v, &ScheduleLogView::editResource, this, &ScheduleHandlerView::slotEditResource);
+}
+
+Project *ScheduleHandlerView::project() const
+{
+    return m_scheduleEditor->project();
 }
 
 void ScheduleHandlerView::currentTabChanged(int)
@@ -768,21 +820,120 @@ ViewBase *ScheduleHandlerView::hitView(const QPoint &/*glpos */)
 
 void ScheduleHandlerView::setGuiActive(bool active) // virtual slot
 {
-    foreach (ViewBase *v, findChildren<ViewBase*>()) {
+    const auto lst = findChildren<ViewBase*>();
+    for (ViewBase *v : lst) {
         v->setGuiActive(active);
     }
-    m_activeview = active ? this : 0;
-    emit guiActivated(this, active);
+    m_activeview = active ? this : nullptr;
+    Q_EMIT guiActivated(this, active);
 }
 
 void ScheduleHandlerView::slotGuiActivated(ViewBase *, bool)
 {
 }
 
+void ScheduleHandlerView::slotOpenNode(Node *node)
+{
+    //debugPlan;
+    if (!node) {
+        return ;
+    }
+    if (!project()) {
+        warnPlan<<Q_FUNC_INFO<<"No project";
+        return;
+    }
+    switch (node->type()) {
+        case Node::Type_Task: {
+                Task *task = static_cast<Task *>(node);
+                TaskDialog *dia = new TaskDialog(*project(), *task, project()->accounts(), this);
+                connect(dia, &QDialog::finished, this, &ScheduleHandlerView::slotTaskEditFinished);
+                dia->open();
+                break;
+            }
+        case Node::Type_Milestone: {
+                // Use the normal task dialog for now.
+                // Maybe milestone should have it's own dialog, but we need to be able to
+                // enter a duration in case we accidentally set a tasks duration to zero
+                // and hence, create a milestone
+                Task *task = static_cast<Task *>(node);
+                TaskDialog *dia = new TaskDialog(*project(), *task, project()->accounts(), this);
+                connect(dia, &QDialog::finished, this, &ScheduleHandlerView::slotTaskEditFinished);
+                dia->open();
+                break;
+            }
+        case Node::Type_Summarytask: {
+                Task *task = dynamic_cast<Task *>(node);
+                Q_ASSERT(task);
+                SummaryTaskDialog *dia = new SummaryTaskDialog(*task, this);
+                connect(dia, &QDialog::finished, this, &ScheduleHandlerView::slotSummaryTaskEditFinished);
+                dia->open();
+                break;
+            }
+        default:
+            break;
+    }
+}
+
+void ScheduleHandlerView::slotTaskEditFinished(int result)
+{
+    TaskDialog *dia = qobject_cast<TaskDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command *cmd = dia->buildCommand();
+        if (cmd) {
+            koDocument()->addCommand(cmd);
+        }
+    }
+    dia->deleteLater();
+}
+
+void ScheduleHandlerView::slotSummaryTaskEditFinished(int result)
+{
+    SummaryTaskDialog *dia = qobject_cast<SummaryTaskDialog*>(sender());
+    if (dia == nullptr) {
+        return;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * cmd = dia->buildCommand();
+        if (cmd) {
+            koDocument()->addCommand(cmd);
+        }
+    }
+    dia->deleteLater();
+}
+
+void ScheduleHandlerView::slotEditResource(Resource *resource)
+{
+    if (resource == nullptr) {
+        return ;
+    }
+    ResourceDialog *dia = new ResourceDialog(*project(), resource, this);
+    connect(dia, &QDialog::finished, this, &ScheduleHandlerView::slotEditResourceFinished);
+    dia->open();
+}
+
+void ScheduleHandlerView::slotEditResourceFinished(int result)
+{
+    //debugPlan;
+    ResourceDialog *dia = qobject_cast<ResourceDialog*>(sender());
+    if (dia == nullptr) {
+        return ;
+    }
+    if (result == QDialog::Accepted) {
+        KUndo2Command * cmd = dia->buildCommand();
+        if (cmd)
+            koDocument()->addCommand(cmd);
+    }
+    dia->deleteLater();
+}
+
+//-------------------------------
 SchedulingRange::SchedulingRange(KoDocument *doc, QWidget *parent)
     : QWidget(parent)
     , m_doc(doc)
-    , m_project(0)
+    , m_project(nullptr)
 {
     setupUi(this);
 
