@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-  Copyright (C) 2006-2008 Dag Andersen <danders@get2net.dk>
-  Copyright (C) 2006-2007 Menard Alexis <danders@get2net>
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+  SPDX-FileCopyrightText: 2006-2008 Dag Andersen <dag.andersen@kdemail.net>
+  SPDX-FileCopyrightText: 2006-2007 Menard Alexis <dag.andersen@kdemail.net>
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPTSCHEDULEEDITOR_H
@@ -61,9 +48,9 @@ public:
     QModelIndexList selectedRows() const;
 
 Q_SIGNALS:
-    void currentChanged(const QModelIndex&);
+    void currentIndexChanged(const QModelIndex&);
     void currentColumnChanged(const QModelIndex&, const QModelIndex&);
-    void selectionChanged(const QModelIndexList&);
+    void selectedIndexesChanged(const QModelIndexList&);
 
 protected Q_SLOTS:
     void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
@@ -92,7 +79,7 @@ public:
     void saveContext(QDomElement &/*context*/) const override;
     
     KoPrintJob *createPrintJob() override;
-    
+
 Q_SIGNALS:
     void calculateSchedule(KPlato::Project*, KPlato::ScheduleManager*);
     void baselineSchedule(KPlato::Project*, KPlato::ScheduleManager*);
@@ -129,6 +116,7 @@ private Q_SLOTS:
     void slotAddSubSchedule();
     void slotDeleteSelection();
     void slotMoveLeft();
+    void slotClaimSchedule();
 
 private:
     ScheduleTreeView *m_view;
@@ -159,12 +147,12 @@ public:
     void setScheduleManager(ScheduleManager *manager) { logModel()->setManager(manager); }
 
     void setFilterWildcard(const QString &filter);
-    QRegExp filterRegExp() const;
+    QRegularExpression filterRegExp() const;
 
 Q_SIGNALS:
-    void currentChanged(const QModelIndex&);
+    void currentIndexChanged(const QModelIndex&);
     void currentColumnChanged(const QModelIndex&, const QModelIndex&);
-    void selectionChanged(const QModelIndexList&);
+    void selectedIndexesChanged(const QModelIndexList&);
 
     void contextMenuRequested(const QModelIndex&, const QPoint&);
 
@@ -239,8 +227,8 @@ class PLANUI_EXPORT ScheduleHandlerView : public SplitterView
     Q_OBJECT
 public:
     ScheduleHandlerView(KoPart *part, KoDocument *doc, QWidget *parent);
-    
-    Project *project() const override { return 0; }
+
+    Project *project() const override;
 
     ScheduleEditor *scheduleEditor() const { return m_scheduleEditor; }
     /// Always returns this (if we are called, we are hit)
@@ -248,8 +236,6 @@ public:
 
 Q_SIGNALS:
     void currentScheduleManagerChanged(KPlato::ScheduleManager*);
-    void editNode(KPlato::Node *node);
-    void editResource(KPlato::Resource *resource);
 
 public Q_SLOTS:
     /// Activate/deactivate the gui (also of subviews)
@@ -260,6 +246,15 @@ protected Q_SLOTS:
     void slotGuiActivated(KPlato::ViewBase *v, bool active) override;
     void currentTabChanged(int i) override;
 
+private Q_SLOTS:
+    void slotOpenNode(KPlato::Node *node);
+
+    void slotTaskEditFinished(int result);
+    void slotSummaryTaskEditFinished(int result);
+
+    void slotEditResource(KPlato::Resource *resource);
+    void slotEditResourceFinished(int result);
+
 private:
     ScheduleEditor *m_scheduleEditor;
 };
@@ -268,7 +263,7 @@ class SchedulingRange : public QWidget, public Ui::SchedulingRange
 {
     Q_OBJECT
 public:
-    SchedulingRange(KoDocument *doc, QWidget *parent = 0);
+    SchedulingRange(KoDocument *doc, QWidget *parent = nullptr);
  
     void setReadWrite(bool rw);
 
