@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2005-2007, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2005-2007, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
@@ -24,7 +11,7 @@
 #include "kptproject.h"
 #include "kptdebug.h"
 
-#include <kcombobox.h>
+#include <KComboBox>
 
 #include <QComboBox>
 #include <QTableWidget>
@@ -40,7 +27,7 @@ ComboBoxDelegate::ComboBoxDelegate(QStringList &list, QObject *parent)
     : QStyledItemDelegate(parent)
 {
     debugPlan;
-    setObjectName("ComboBoxDelegate");
+    setObjectName(QStringLiteral("ComboBoxDelegate"));
     m_list = list;
 }
 
@@ -76,13 +63,12 @@ void ComboBoxDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionV
 
 //----------------------
 
-WBSDefinitionPanel::WBSDefinitionPanel(Project &project, WBSDefinition &def, QWidget *p, const char *n)
+WBSDefinitionPanel::WBSDefinitionPanel(Project &project, WBSDefinition &def, QWidget *p)
     : QWidget(p),
       m_project(project),
       m_def(def),
       selectedRow(-1)
 {
-    setObjectName(n);
     setupUi(this);
     
     projectCode->setText(m_def.projectCode());
@@ -102,7 +88,7 @@ WBSDefinitionPanel::WBSDefinitionPanel(Project &project, WBSDefinition &def, QWi
     debugPlan<<"Map size="<<lev.count();
     QMap<int, WBSDefinition::CodeDef>::const_iterator it;
     for (it = lev.begin(); it != lev.end(); ++it) {
-        sl << QString("%1").arg(it.key());
+        sl << QStringLiteral("%1").arg(it.key());
         QTableWidgetItem *item = new QTableWidgetItem();
         item->setData(Qt::DisplayRole, it.value().code);
         levelsTable->setItem(i, 0, item);
@@ -155,7 +141,7 @@ bool WBSDefinitionPanel::ok() {
 }
 
 void WBSDefinitionPanel::slotChanged() {
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void WBSDefinitionPanel::slotSelectionChanged() {
@@ -164,9 +150,9 @@ void WBSDefinitionPanel::slotSelectionChanged() {
     QList<QTableWidgetItem *> items = levelsTable->selectedItems();
     if (items.count() == 2 && items[0]->row() == items[1]->row()) {
         selectedRow = items[0]->row();
-        s = QString("Row[%1]=selected ").arg(selectedRow);
+        s = QStringLiteral("Row[%1]=selected ").arg(selectedRow);
     } else {
-        s = "None selected";
+        s = QStringLiteral("None selected");
     }
     removeBtn->setEnabled(selectedRow != -1);
     debugPlan<<s;
@@ -193,7 +179,7 @@ void WBSDefinitionPanel::slotAddBtnClicked() {
     }
     i++;
     levelsTable->insertRow(i);
-    levelsTable->setVerticalHeaderItem(i, new QTableWidgetItem(QString("%1").arg(level->value())));
+    levelsTable->setVerticalHeaderItem(i, new QTableWidgetItem(QStringLiteral("%1").arg(level->value())));
     QTableWidgetItem *item = new QTableWidgetItem();
     item->setData(Qt::DisplayRole, (m_def.codeList().value(m_def.defaultCodeIndex())));
     levelsTable->setItem(i, 0, item);
