@@ -1,8 +1,8 @@
 /*
 * KPlato Report Plugin
-* Copyright (C) 2007-2009 by Adam Pigg (adam@piggz.co.uk)
-* Copyright (C) 2010 by Dag Andersen <danders@get2net.dk>
-* Copyright (C) 2016 by Dag Andersen <danders@get2net.dk>
+* SPDX-FileCopyrightText: 2007-2009 Adam Pigg (adam@piggz.co.uk)
+* SPDX-FileCopyrightText: 2010 Dag Andersen <dag.andersen@kdemail.net>
+* SPDX-FileCopyrightText: 2016 Dag Andersen <dag.andersen@kdemail.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -72,9 +72,9 @@ PLANUI_EXPORT QList<ReportData*> Report::createBaseReportDataModels(QObject *par
     data = new ProjectReportData(parent);
     lst << data;
 
-    foreach (ReportData *r, lst) {
+    for (ReportData *r : std::as_const(lst)) {
         QList<ReportData*> sub;
-        foreach (ReportData *d, lst) {
+        for (ReportData *d : std::as_const(lst)) {
             if (d->isSubDataSource()) {
                 sub << d;
             }
@@ -86,7 +86,7 @@ PLANUI_EXPORT QList<ReportData*> Report::createBaseReportDataModels(QObject *par
 
 PLANUI_EXPORT ReportData *Report::findReportData(const QList<ReportData*> &lst, const QString &type)
 {
-    foreach(ReportData *r, lst) {
+    for (ReportData *r ; lst) {
         if (r->objectName() == type) {
             return r;
         }
@@ -139,7 +139,7 @@ bool ReportData::open()
 
     if (! m_sortlist.isEmpty()) {
         QAbstractItemModel *sourcemodel = m_model.sourceModel();
-        foreach (const SortedField &sort, m_sortlist) {
+        for (const SortedField &sort : std::as_const(m_sortlist)) {
             int col = fieldNumber(sort.field);
             QSortFilterProxyModel *sf = new QSortFilterProxyModel(&m_model);
             sf->setSourceModel(sourcemodel);
@@ -287,7 +287,7 @@ qint64 ReportData::recordCount() const {
 QStringList ReportData::dataSources() const
 {
      QStringList lst;
-     foreach (ReportData *r, m_subdatasources) {
+     for (ReportData *r : std::as_const(m_subdatasources)) {
          if (r->isSubDataSource()) {
              lst << r->objectName();
          }
@@ -298,7 +298,7 @@ QStringList ReportData::dataSources() const
 QStringList ReportData::dataSourceNames() const
 {
     QStringList lst;
-    foreach (ReportData *r, m_subdatasources) {
+    for (ReportData *r : std::as_const(m_subdatasources)) {
         if (r->isSubDataSource()) {
             lst << r->sourceName();
         }
@@ -752,7 +752,7 @@ QStringList ChartReportData::fieldNames() const
 void ChartReportData::addExpression(const QString &field, const QVariant &/*value*/, char /*relation*/)
 {
 //     debugPlan<<field<<value<<relation;
-    QStringList lst = field.split('=', QString::SkipEmptyParts);
+    QStringList lst = field.split('=', Qt::SkipEmptyParts);
     if (lst.count() == 2) {
         QString key = lst[ 0 ].trimmed().toLower();
         if (m_keywords.contains(key)) {
