@@ -1,7 +1,7 @@
 /*
  * KPlato Report Plugin
- * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
- * Copyright (C) 2010, 2011, 2012 by Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2007-2008 Adam Pigg (adam@piggz.co.uk)
+ * SPDX-FileCopyrightText: 2010, 2011, 2012 Dag Andersen <dag.andersen@kdemail.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -55,13 +55,13 @@
 #include "KoIcon.h"
 #include <KoXmlReader.h>
 
-#include <kactionmenu.h>
-#include <kactioncollection.h>
-#include <kstandardaction.h>
-#include <kstandardguiitem.h>
-#include <kguiitem.h>
-#include <kmessagebox.h>
-#include <ktoolbar.h>
+#include <KActionMenu>
+#include <KActionCollection>
+#include <KStandardAction>
+#include <KStandardGuiItem>
+#include <KGuiItem>
+#include <KMessageBox>
+#include <KToolBar>
 
 #include <QCloseEvent>
 #include <QPainter>
@@ -80,7 +80,7 @@
 #include <QActionGroup>
 #include <QStackedWidget>
 #include <QAction>
-#include <qpushbutton.h>
+#include <QPushButton>
 #include <QMimeDatabase>
 #include <QFileDialog>
 
@@ -163,7 +163,7 @@ ReportView::ReportView(KoPart *part, KoDocument *doc, QWidget *parent)
     setObjectName("ReportView");
 
     QLayout *l = new QHBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_stack = new QStackedWidget(this);
     l->addWidget(m_stack);
 
@@ -195,7 +195,7 @@ void ReportView::slotViewReport()
         reportWidget()->loadXML(reportDesigner()->document());
     }
     if (reportDesigner()->isModified()) {
-        emit optionsModified();
+        Q_EMIT optionsModified();
         reportDesigner()->setModified(false);
     }
     m_stack->setCurrentIndex(0);
@@ -295,7 +295,7 @@ ReportWidget::ReportWidget(KoPart *part, KoDocument *doc, QWidget *parent)
     m_reportScene->setBackgroundBrush(palette().brush(QPalette::Dark));
 
     QVBoxLayout *l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     l->addWidget(m_reportView);
     m_pageSelector = new ReportNavigator(this);
     l->addWidget(m_pageSelector);
@@ -634,7 +634,7 @@ ReportDesigner::ReportDesigner(KoPart *part, KoDocument *doc, QWidget *parent)
     m_groupsectioneditor(new GroupSectionEditor(this))
 {
     QVBoxLayout *l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_scrollarea = new QScrollArea(this);
     l->addWidget(m_scrollarea);
 
@@ -770,18 +770,18 @@ void ReportDesigner::setData()
     connect(this, SIGNAL(pasteActivated()), m_designer, SLOT(slotEditPaste()));
     connect(this, SIGNAL(deleteActivated()), m_designer, SLOT(slotEditDelete()));
 
-    emit reportheaderShown(m_designer->section(KReportSectionData::ReportHeader));
-    emit reportfooterShown(m_designer->section(KReportSectionData::ReportFooter));
-    emit headerFirstpageShown(m_designer->section(KReportSectionData::PageHeaderFirst));
-    emit headerLastpageShown(m_designer->section(KReportSectionData::PageHeaderLast));
-    emit headerOddpagesShown(m_designer->section(KReportSectionData::PageHeaderOdd));
-    emit headerEvenpagesShown(m_designer->section(KReportSectionData::PageHeaderEven));
-    emit headerAllpagesShown(m_designer->section(KReportSectionData::PageHeaderAny));
-    emit footerFirstpageShown(m_designer->section(KReportSectionData::PageFooterFirst));
-    emit footerLastpageShown(m_designer->section(KReportSectionData::PageFooterLast));
-    emit footerOddpagesShown(m_designer->section(KReportSectionData::PageFooterOdd));
-    emit footerEvenpagesShown(m_designer->section(KReportSectionData::PageFooterEven));
-    emit footerAllpagesShown(m_designer->section(KReportSectionData::PageFooterAny));
+    Q_EMIT reportheaderShown(m_designer->section(KReportSectionData::ReportHeader));
+    Q_EMIT reportfooterShown(m_designer->section(KReportSectionData::ReportFooter));
+    Q_EMIT headerFirstpageShown(m_designer->section(KReportSectionData::PageHeaderFirst));
+    Q_EMIT headerLastpageShown(m_designer->section(KReportSectionData::PageHeaderLast));
+    Q_EMIT headerOddpagesShown(m_designer->section(KReportSectionData::PageHeaderOdd));
+    Q_EMIT headerEvenpagesShown(m_designer->section(KReportSectionData::PageHeaderEven));
+    Q_EMIT headerAllpagesShown(m_designer->section(KReportSectionData::PageHeaderAny));
+    Q_EMIT footerFirstpageShown(m_designer->section(KReportSectionData::PageFooterFirst));
+    Q_EMIT footerLastpageShown(m_designer->section(KReportSectionData::PageFooterLast));
+    Q_EMIT footerOddpagesShown(m_designer->section(KReportSectionData::PageFooterOdd));
+    Q_EMIT footerEvenpagesShown(m_designer->section(KReportSectionData::PageFooterEven));
+    Q_EMIT footerAllpagesShown(m_designer->section(KReportSectionData::PageFooterAny));
 
     m_designer->setModified(false);
     slotModified();
@@ -823,22 +823,22 @@ void ReportDesigner::createDockers()
 
     // allow only the following item types, there is not appropriate data for others
     const QStringList itemtypes = QStringList()
-    << QLatin1String("org.kde.kreport.label")
-    << QLatin1String("org.kde.kreport.plan.text") // replaces text
-    << QLatin1String("org.kde.kreport.field")
-    << QLatin1String("org.kde.kreport.line")
-    << QLatin1String("org.kde.kreport.checkbox")
-    << QLatin1String("org.kde.kreport.chart")
-    << QLatin1String("org.kde.kreport.web"); // can be used for fixed sized rich text
+    << QStringLiteral("org.kde.kreport.label")
+    << QStringLiteral("org.kde.kreport.plan.text") // replaces text
+    << QStringLiteral("org.kde.kreport.field")
+    << QStringLiteral("org.kde.kreport.line")
+    << QStringLiteral("org.kde.kreport.checkbox")
+    << QStringLiteral("org.kde.kreport.chart")
+    << QStringLiteral("org.kde.kreport.web"); // can be used for fixed sized rich text
 // TODO: proper tooltips
 //     const QStringList itemTooltips = QStringList()
-//     << xi18nc("@into:tooltip", "Label")
-//     << xi18nc("@into:tooltip", "Text element with variable height")
-//     << xi18nc("@into:tooltip", "Text element")
-//     << xi18nc("@into:tooltip", "Line")
-//     << xi18nc("@into:tooltip", "Checkbox")
-//     << xi18nc("@into:tooltip", "Chart")
-//     << xi18nc("@into:tooltip", "Text element with fixed size");
+//     << xi18nc("@info:tooltip", "Label")
+//     << xi18nc("@info:tooltip", "Text element with variable height")
+//     << xi18nc("@info:tooltip", "Text element")
+//     << xi18nc("@info:tooltip", "Line")
+//     << xi18nc("@info:tooltip", "Checkbox")
+//     << xi18nc("@info:tooltip", "Chart")
+//     << xi18nc("@info:tooltip", "Text element with fixed size");
 
     QActionGroup *ag = new QActionGroup(this);
     QMap<int, QToolButton*> tblst;
@@ -916,7 +916,7 @@ void ReportDesigner::createDockers()
 
 void ReportDesigner::setReportData(const QString &tag)
 {
-    emit optionsModified();
+    Q_EMIT optionsModified();
     ReportData *rd = Report::findReportData(m_reportdatamodels, tag);
     if (rd) {
         rd = rd->clone(); // KReportDesigner takes ownership, so give it a clone it can delete
@@ -929,7 +929,7 @@ void ReportDesigner::setReportData(const QString &tag)
 QStandardItemModel *ReportDesigner::createSourceModel(QObject *parent) const
 {
     QStandardItemModel *m = new QStandardItemModel(parent);
-    foreach (ReportData *r, m_reportdatamodels) {
+    for (ReportData *r : std::as_const(m_reportdatamodels)) {
         if (r->isMainDataSource()) {
             QStandardItem *item = new QStandardItem(r->sourceName());
             item->setData(r->objectName(), Reports::TagRole);
@@ -954,7 +954,7 @@ void ReportDesigner::slotInsertAction()
 
 void ReportDesigner::slotItemInserted(const QString &)
 {
-    emit resetButtonState(false);
+    Q_EMIT resetButtonState(false);
 }
 
 void ReportDesigner::slotSectionToggled(bool on)
@@ -1137,7 +1137,8 @@ void GroupSectionEditor::slotRemoveRows()
         return;
     }
     QList<int> rows;
-    foreach (const QModelIndex &idx, gsw.view->selectionModel()->selectedRows()) {
+    const QModelIndexList indexes = gsw.view->selectionModel()->selectedRows();
+    for (const QModelIndex &idx : indexes) {
         rows <<idx.row();
     }
     qSort(rows);
@@ -1156,14 +1157,15 @@ void GroupSectionEditor::slotMoveRowUp()
         return;
     }
     QList<int> rows;
-    foreach (const QModelIndex &idx, gsw.view->selectionModel()->selectedRows()) {
+    const QModelIndexList indexes = gsw.view->selectionModel()->selectedRows();
+    for (const QModelIndex &idx : indexes) {
         rows <<idx.row();
     }
     qSort(rows);
     if (rows.isEmpty() || rows.first() == 0) {
         return;
     }
-    foreach (int row, rows) {
+    for (int row : std::as_const(rows)) {
         QList<QStandardItem*> items = model.takeRow(row);
         KReportDesignerSectionDetailGroup *g = sd->groupSection(row);
         bool showgh = g->groupHeaderVisible();
@@ -1188,7 +1190,8 @@ void GroupSectionEditor::slotMoveRowDown()
         return;
     }
     QList<int> rows;
-    foreach (const QModelIndex &idx, gsw.view->selectionModel()->selectedRows()) {
+    const QModelIndexList indexes = gsw.view->selectionModel()->selectedRows();
+    for (const QModelIndex &idx : indexes) {
         rows <<idx.row();
     }
     qSort(rows);
