@@ -1,24 +1,11 @@
 /*  This file is part of the KDE Libraries
- *  Copyright (C) 1998 Thomas Tanghus (tanghus@earthling.net)
+ *  SPDX-FileCopyrightText: 1998 Thomas Tanghus (tanghus@earthling.net)
  *  Additions 1999-2000 by Espen Sand (espen@kde.org)
  *                      and Holger Freyther <freyther@kde.org>
  *            2005-2009 Olivier Goffart <ogoffart @ kde.org>
  *            2006      Tobias Koenig <tokoe@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KODIALOG_H
@@ -29,8 +16,8 @@ class QMenu;
 class KoDialogPrivate;
 
 #include <kowidgets_export.h>
-#include <kconfiggroup.h>
-#include <kguiitem.h>
+#include <KConfigGroup>
+#include <KGuiItem>
 
 #include <QDialog>
 
@@ -57,7 +44,7 @@ class KoDialogPrivate;
  * for a central KDE control tool. The following buttons are available:
  * OK, Cancel/Close, Apply/Try, Default, Help and three user definable
  * buttons: User1, User2 and User3. You must specify the text of the UserN
- * buttons. Each button emit a signal, so you can choose to connect that signal.
+ * buttons. Each button Q_EMIT a signal, so you can choose to connect that signal.
  *
  * The default action of the Help button will open the help system if you have
  * provided a path to the help text.
@@ -139,8 +126,6 @@ public:
         Try     = 0x00000010, ///< Show Try button.
         Cancel  = 0x00000020, ///< Show Cancel-button. (this button reject()s the dialog; result set to QDialog::Rejected)
         Close   = 0x00000040, ///< Show Close-button. (this button closes the dialog)
-        No      = 0x00000080, ///< Show No button. (this button closes the dialog and sets the result to KoDialog::No)
-        Yes     = 0x00000100, ///< Show Yes button. (this button closes the dialog and sets the result to KoDialog::Yes)
         Reset   = 0x00000200, ///< Show Reset button
         Details = 0x00000400, ///< Show Details button. (this button will show the detail widget set with setDetailsWidget)
         User1   = 0x00001000, ///< Show User defined button 1.
@@ -165,7 +150,7 @@ public:
      * @param parent The parent of the dialog.
      * @param flags  The widget flags passed to the QDialog constructor
      */
-    explicit KoDialog(QWidget *parent = 0, Qt::WindowFlags flags = 0);
+    explicit KoDialog(QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());
 
     /**
      * Destroys the dialog.
@@ -367,32 +352,6 @@ public:
      */
     QPushButton *button(ButtonCode id) const;
 
-    /**
-     * Returns the number of pixels that should be used between a
-     * dialog edge and the outermost widget(s) according to the KDE standard.
-     *
-     * @deprecated Use the style's pixelMetric() function to query individual margins.
-     * Different platforms may use different values for the four margins.
-     */
-    static int marginHint();
-
-    /**
-     * Returns the number of pixels that should be used between
-     * widgets inside a dialog according to the KDE standard.
-     *
-     * @deprecated Use the style's layoutSpacing() function to query individual spacings.
-     * Different platforms may use different values depending on widget types and pairs.
-     */
-    static int spacingHint();
-
-    /**
-     * Returns the number of pixels that should be used to visually
-     * separate groups of related options in a dialog according to
-     * the KDE standard.
-     * @since 4.2
-     */
-    static int groupSpacingHint();
-
     /**
      * @enum CaptionFlag
      * Used to specify how to construct a window caption
@@ -435,7 +394,7 @@ public:
      * @return the created caption
      */
     static QString makeStandardCaption(const QString &userCaption,
-                                       QWidget *window = 0,
+                                       QWidget *window = nullptr,
                                        CaptionFlags flags = HIGCompliantCaption);
 
     /**
@@ -464,27 +423,6 @@ public:
      */
     static void resizeLayout(QLayout *lay, int margin, int spacing);
 
-    /**
-     * Centers @p widget on the desktop, taking multi-head setups into
-     * account. If @p screen is -1, @p widget will be centered on its
-     * current screen (if it was shown already) or on the primary screen.
-     * If @p screen is -3, @p widget will be centered on the screen that
-     * currently contains the mouse pointer.
-     * @p screen will be ignored if a merged display (like Xinerama) is not
-     * in use, or merged display placement is not enabled in kdeglobals.
-     */
-    static void centerOnScreen(QWidget *widget, int screen = -1);
-
-    /**
-     * Places @p widget so that it doesn't cover a certain @p area of the screen.
-     * This is typically used by the "find dialog" so that the match it finds can
-     * be read.
-     * For @p screen, see centerOnScreen
-     * @return true on success (widget doesn't cover area anymore, or never did),
-     * false on failure (not enough space found)
-     */
-    static bool avoidArea(QWidget *widget, const QRect &area, int screen = -1);
-
     /**
      * Sets the main widget of the dialog.
      */
@@ -503,12 +441,12 @@ public:
     /**
      * Reimplemented from QDialog.
      */
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
     /**
      * Reimplemented from QDialog.
      */
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    QSize minimumSizeHint() const override;
 
     /**
      * Returns the status of the Details button.
@@ -704,18 +642,6 @@ Q_SIGNALS:
      */
     void okClicked();
 
-    /**
-     * The Yes button was pressed. This signal is only emitted if
-     * slotButtonClicked() is not replaced
-     */
-    void yesClicked();
-
-    /**
-     * The No button was pressed. This signal is only emitted if
-     * slotButtonClicked() is not replaced
-     */
-    void noClicked();
-
     /**
      * The Cancel button was pressed. This signal is only emitted if
      * slotButtonClicked() is not replaced
@@ -744,22 +670,6 @@ Q_SIGNALS:
      */
     void hidden();
 
-    /**
-     * The dialog has finished.
-     *
-     * A dialog emits finished after a user clicks a button that ends
-     * the dialog.
-     *
-     * This signal is also emitted when you call hide()
-     *
-     * If you have stored a pointer to the
-     * dialog do @em not try to delete the pointer in the slot that is
-     * connected to this signal.
-     *
-     * You should use deleteLater() instead.
-     */
-    void finished();
-
     /**
      * The detailsWidget is about to get shown. This is your last chance
      * to call setDetailsWidget if you haven't done so yet.
@@ -771,7 +681,7 @@ protected:
      * Emits the #hidden signal. You can connect to that signal to
      * detect when a dialog has been closed.
      */
-    void hideEvent(QHideEvent *) Q_DECL_OVERRIDE;
+    void hideEvent(QHideEvent *) override;
 
     /**
      * Detects when a dialog is being closed from the window manager
@@ -779,12 +689,12 @@ protected:
      * is activated. Otherwise standard QDialog behavior
      * will take place.
      */
-    void closeEvent(QCloseEvent *e) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *e) override;
 
     /**
      * @internal
      */
-    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *) override;
 
 protected Q_SLOTS:
     /**
@@ -819,7 +729,7 @@ protected Q_SLOTS:
     void updateGeometry();
 
 private:
-    KoDialog(KoDialogPrivate &dd, QWidget *parent, Qt::WindowFlags flags = 0);
+    KoDialog(KoDialogPrivate &dd, QWidget *parent, Qt::WindowFlags flags = Qt::WindowFlags());
     KoDialogPrivate *const d_ptr;
 
 private:
