@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007,2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007, 2010 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -23,7 +10,7 @@
 #include "KoPageLayoutWidget.h"
 #include "KoPagePreviewWidget.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <WidgetsDebug.h>
 
 #include <QCheckBox>
@@ -34,7 +21,7 @@
 class Q_DECL_HIDDEN KoPageLayoutDialog::Private
 {
 public:
-    Private() : pageLayoutWidget(0), documentCheckBox(0) {}
+    Private() : pageLayoutWidget(nullptr), documentCheckBox(nullptr) {}
     KoPageLayoutWidget *pageLayoutWidget;
     QCheckBox *documentCheckBox;
 };
@@ -103,7 +90,7 @@ bool KoPageLayoutDialog::applyToDocument() const
 
 void KoPageLayoutDialog::showApplyToDocument(bool on)
 {
-    if (on && d->documentCheckBox == 0) {
+    if (on && d->documentCheckBox == nullptr) {
         for (int i = 0; i < children().count(); ++i) {
             if (QDialogButtonBox *buttonBox = qobject_cast<QDialogButtonBox*>(children()[i])) {
                 d->documentCheckBox = new QCheckBox(i18n("Apply to document"), buttonBox);
