@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Thomas Zander <zander@kde.org>
- * Copyright (C) 2006 Gary Cramblitt <garycramblitt@comcast.net>
+ * SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Gary Cramblitt <garycramblitt@comcast.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // clazy:excludeall=qstring-arg
@@ -132,7 +119,7 @@ void KoPagePreviewWidget::drawPage(QPainter &painter, qreal zoom, const QRect &d
             painter.drawRect(qRound(textArea.x() + i * columnWidth), textArea.y(), width, textArea.height());
     } else {
         qreal totalRelativeWidth = 0.0;
-        foreach(const KoColumns::ColumnDatum &cd, d->columns.columnData) {
+        for (const KoColumns::ColumnDatum &cd : std::as_const(d->columns.columnData)) {
             totalRelativeWidth += cd.relativeWidth;
         }
         int relativeColumnXOffset = 0;
