@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
- * Copyright (C) 2009 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2009 Boudewijn Rempt <boud@valdyas.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 // clazy:excludeall=qstring-arg
 #include "KoProgressUpdater.h"
@@ -38,7 +25,7 @@ class Q_DECL_HIDDEN KoProgressUpdater::Private
 public:
 
     Private(KoProgressUpdater *_parent, KoProgressProxy *p, Mode _mode,
-            QTextStream *output_ = 0)
+            QTextStream *output_ = nullptr)
         : parent(_parent)
         , progressBar(p)
         , mode(_mode)
@@ -83,7 +70,7 @@ KoProgressUpdater::KoProgressUpdater(KoProgressProxy *progressBar,
 KoProgressUpdater::~KoProgressUpdater()
 {
     if (d->output) {
-        Private::logEvents(*d->output, d, referenceTime(), "");
+        Private::logEvents(*d->output, d, referenceTime(), QString());
     }
     d->progressBar->setValue(d->progressBar->maximum());
 
@@ -152,7 +139,7 @@ QPointer<KoUpdater> KoProgressUpdater::startSubtask(int weight,
 
 void KoProgressUpdater::cancel()
 {
-    foreach(KoUpdaterPrivate *updater, d->subtasks) {
+    for (KoUpdaterPrivate *updater : std::as_const(d->subtasks)) {
         updater->setProgress(100);
         updater->interrupt();
     }
@@ -179,7 +166,7 @@ void KoProgressUpdater::updateUi()
 
     if (d->updated) {
         int totalProgress = 0;
-        foreach(QPointer<KoUpdaterPrivate> updater, d->subtasks) {
+        for (QPointer<KoUpdaterPrivate> updater : std::as_const(d->subtasks)) { // clazy:exclude=range-loop-reference
             if (updater->interrupted()) {
                 d->currentProgress = -1;
                 return;
@@ -217,7 +204,7 @@ bool KoProgressUpdater::interrupted() const
 
 bool KoProgressUpdater::hasOutput() const
 {
-    return d->output != 0;
+    return d->output != nullptr;
 }
 
 void KoProgressUpdater::Private::logEvents(QTextStream& out,
@@ -225,11 +212,12 @@ void KoProgressUpdater::Private::logEvents(QTextStream& out,
                                            const QTime& startTime,
                                            const QString& prefix) {
     // initial implementation: write out the names of all events
-    foreach (QPointer<KoUpdaterPrivate> p, updater->subtasks) {
+    for (QPointer<KoUpdaterPrivate> p : std::as_const(updater->subtasks)) { // clazy:exclude=range-loop-reference
         if (!p) continue;
-        foreach (const KoUpdaterPrivate::TimePoint &tp, p->getPoints()) {
+        const QVector<KoUpdaterPrivate::TimePoint> points = p->getPoints();
+        for  (const KoUpdaterPrivate::TimePoint &tp : points) {
             out << prefix+p->objectName() << '\t'
-                    << startTime.msecsTo(tp.time) << '\t' << tp.value << endl;
+                    << startTime.msecsTo(tp.time) << '\t' << tp.value << '\n';
         }
     }
 }
