@@ -1,39 +1,24 @@
 /* This file is part of the KDE project
-   Copyright (C) 2009, 2011, 2012 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2009, 2011, 2012 Dag Andersen <dag.andersen@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // clazy:excludeall=qstring-arg
 #include "kplatoimport.h"
 
-#include <kptmaindocument.h>
 #include <kpttask.h>
 #include <kptnode.h>
 #include <kptresource.h>
 #include <kptdocuments.h>
 #include "kptdebug.h"
 
-#include <QTextCodec>
 #include <QByteArray>
 #include <QString>
 #include <QTextStream>
 #include <QFile>
 
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 
 #include <KoFilterChain.h>
 #include <KoFilterManager.h>
@@ -56,7 +41,7 @@ KoFilter::ConversionStatus KPlatoImport::convert(const QByteArray& from, const Q
     if ((from != "application/x-vnd.kde.kplato") || (to != "application/x-vnd.kde.plan")) {
         return KoFilter::NotImplemented;
     }
-    KoDocument *part = 0;
+    KoDocument *part = nullptr;
     bool batch = false;
     if (m_chain->manager()) {
         batch = m_chain->manager()->getBatchMode();
@@ -68,7 +53,7 @@ KoFilter::ConversionStatus KPlatoImport::convert(const QByteArray& from, const Q
         //debugPlan<<"online";
         part = m_chain->outputDocument();
     }
-    if (part == 0) {
+    if (part == nullptr) {
         errorPlan << "Cannot open document";
         return KoFilter::InternalError;
     }
