@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2009 Dag Andersen <danders@get2net.dk>
- * Copyright (C) 2011 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2009 Dag Andersen <dag.andersen@kdemail.net>
+ * SPDX-FileCopyrightText: 2011 Dag Andersen <dag.andersen@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef PLANTJSCHEDULER_H
@@ -26,6 +13,7 @@
 #include "kptschedulerplugin.h"
 
 #include "kptdatetime.h"
+#include "kptappointment.h"
 
 #include <QThread>
 #include <QObject>
@@ -57,14 +45,15 @@ namespace KPlato
 }
 using namespace KPlato;
 
-class PlanTJScheduler : public KPlato::SchedulerThread
+class PLANTJ_EXPORT PlanTJScheduler : public KPlato::SchedulerThread
 {
     Q_OBJECT
 
 private:
 
 public:
-    PlanTJScheduler(Project *project, ScheduleManager *sm, ulong granularity, QObject *parent = 0);
+    PlanTJScheduler(Project *project, ScheduleManager *sm, ulong granularity, QObject *parent = nullptr);
+    explicit PlanTJScheduler(ulong granularity = 0, QObject *parent = nullptr);
     ~PlanTJScheduler() override;
 
     bool check();
@@ -76,6 +65,7 @@ public:
     /// Fetch project data from TJ structure
     bool kplatoFromTJ();
 
+    void schedule(SchedulingContext &context) override;
 
 Q_SIGNALS:
     void sigCalculationStarted(KPlato::Project*, KPlato::ScheduleManager*);
@@ -85,6 +75,8 @@ Q_SIGNALS:
 public Q_SLOTS:
     void slotMessage(int type, const QString &msg, TJ::CoreAttributes *object);
 
+    void cancelScheduling(SchedulingContext &context) override;
+
 protected:
     void run() override;
 
@@ -92,22 +84,26 @@ protected:
 
     TJ::Resource *addResource(KPlato::Resource *resource);
     void addTasks();
-    void addWorkingTime(KPlato::Task *task, TJ::Task *job);
-    TJ::Task *addTask(KPlato::Task *task , TJ::Task *parent = 0);
+    void addWorkingTime(const KPlato::Task *task, TJ::Task *job);
+    TJ::Task *addTask(const KPlato::Node *node , TJ::Task *parent = nullptr);
     void addDependencies();
     void addPrecedes(const Relation *rel);
     void addDepends(const Relation *rel);
-    void addDependencies(Task *task);
+    void addDependencies(Node *task);
     void setConstraints();
-    void setConstraint(TJ::Task *job, KPlato::Task *task);
+    void setConstraint(TJ::Task *job, KPlato::Node *task);
     TJ::Task *addStartNotEarlier(Node *task);
     TJ::Task *addFinishNotLater(Node *task);
     void addRequests();
-    void addRequest(TJ::Task *job, Task *task);
+    void addRequest(TJ::Task *job, Node *task);
     void addStartEndJob();
-    bool taskFromTJ(TJ::Task *job, Task *task);
-    void calcPertValues(Task *task);
-    Duration calcPositiveFloat(Task *task);
+    bool taskFromTJ(TJ::Task *job, Node *task);
+    bool taskFromTJ(Project *project, TJ::Task *job, Node *task);
+    void calcPertValues(Node *task);
+    Duration calcPositiveFloat(Node *task);
+    Resource *resource(Project *project, TJ::Resource *tjResource);
+
+    void populateProjects(KPlato::SchedulingContext &context);
 
     static bool exists(QList<CalendarDay*> &lst, CalendarDay *day);
     static int toTJDayOfWeek(int day);
@@ -116,23 +112,30 @@ protected:
     AppointmentInterval fromTJInterval(const TJ::Interval &tji, const QTimeZone &tz);
     static TJ::Interval toTJInterval(const QDateTime &start, const QDateTime &end, ulong tjGranularity);
     static TJ::Interval toTJInterval(const QTime &start, const QTime &end, ulong tjGranularity);
-
-
+    
 private:
     ulong tjGranularity() const;
+    void insertProject(KoDocument *doc, int priority, KPlato::SchedulingContext &context);
+    void insertBookings(KPlato::SchedulingContext &context);
+    void addTasks(const KPlato::Node *parent, TJ::Task *tjParent = nullptr, int projectPriority = 0);
+    void addPastAppointments(Node *task);
+
+    void calculateParallel(KPlato::SchedulingContext &context);
+    void calculateSequential(KPlato::SchedulingContext &context);
 
 private:
     MainSchedule *m_schedule;
     bool m_recalculate;
+    DateTime m_recalculateFrom;
     bool m_usePert;
     bool m_backward;
-    TJ::Project *m_tjProject;
+    QPointer<TJ::Project> m_tjProject;
 //     Task *m_backwardTask;
 
-    QMap<TJ::Task*, Task*> m_taskmap;
+    QMap<TJ::Task*, Node*> m_taskmap;
     QMap<TJ::Resource*, Resource*> m_resourcemap;
-
-    ulong m_granularity;
+    QMap<QString, Resource*> m_resourceIds;
+    QList<Task*> m_durationTasks;
 };
 
 #endif // PLANTJSCHEDULER_H
