@@ -1,7 +1,7 @@
 /*
  * CoreAttributesTreeIterator.h - TaskJuggler
  *
- * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
+ * SPDX-FileCopyrightText: 2001, 2002, 2003, 2004 Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -53,8 +53,8 @@ template <class T>
 T*
 CoreAttributesTreeIteratorT<T>::operator++()
 {
-    if (current == 0)
-        return 0;
+    if (current == nullptr)
+        return nullptr;
 
     while (current != root)
     {
@@ -78,7 +78,7 @@ CoreAttributesTreeIteratorT<T>::operator++()
         if (iMode == parentAfterLeaves)
             return current;
     }
-    return (current = 0);
+    return (current = nullptr);
 }
 
 typedef CoreAttributesTreeIteratorT<CoreAttributes> CoreAttributesTreeIterator;
