@@ -1,8 +1,8 @@
 /*
  * Utility.cpp - TaskJuggler
  *
- * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
- * Copyright (c) 2011 by Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2001, 2002, 2003, 2004 Chris Schlaeger <cs@kde.org>
+ * SPDX-FileCopyrightText: 2011 Dag Andersen <dag.andersen@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
@@ -42,10 +42,10 @@ int unsetenv (const char *var);
 namespace TJ
 {
 
-static QMap<QString, const char*> TZDict;
+static QMap<QString, const char*> TZDict; // clazy:exclude=non-pod-global-static
 static bool TZDictReady = false;
 
-static QString UtilityError;
+static QString UtilityError; // clazy:exclude=non-pod-global-static
 
 /* localtime() calls are fairly expensive, so we implement a hashtable based
  * cache to avoid redundant calls for the same value. Changing the timezone
@@ -53,7 +53,7 @@ static QString UtilityError;
 class LtHashTabEntry
 {
 public:
-    LtHashTabEntry() : tms(0), next(0) {}
+    LtHashTabEntry() : tms(nullptr), next(nullptr) {}
     ~LtHashTabEntry() { /*qDebug()<<"~LtHashTabEntry";*/ delete tms; }
     time_t t;
     struct tm* tms;
@@ -61,7 +61,7 @@ public:
 };
 
 static long LTHASHTABSIZE;
-static LtHashTabEntry** LtHashTab = 0;
+static LtHashTabEntry** LtHashTab = nullptr;
 
 bool
 isRichText(const QString& str)
@@ -160,16 +160,16 @@ void initUtility(long dictSize)
 
     LtHashTab = new LtHashTabEntry*[LTHASHTABSIZE = dictSize];
     for (long i = 0; i < LTHASHTABSIZE; ++i)
-        LtHashTab[i] = 0;
+        LtHashTab[i] = nullptr;
 }
 
 void exitUtility()
 {
-    qDebug()<<"exitUtility:"<<LtHashTab;
+    //qDebug()<<"exitUtility:"<<LtHashTab;
     if (!LtHashTab)
         return;
 
-    qDebug()<<"exitUtility:"<<LTHASHTABSIZE;
+    //qDebug()<<"exitUtility:"<<LTHASHTABSIZE;
     for (long i = 0; i < LTHASHTABSIZE; ++i)
         for (LtHashTabEntry* htep = LtHashTab[i]; htep;)
         {
@@ -179,7 +179,7 @@ void exitUtility()
         }
 
     delete [] LtHashTab;
-    LtHashTab = 0;
+    LtHashTab = nullptr;
 }
 
 bool
@@ -196,7 +196,7 @@ setTimezone(const char* tZone)
      * will just copy the wrong value to tzname[0] (glibc < 2.5) or fall back
      * to UTC. */
     tzset();
-    if (timezone2tz(tZone) == 0 &&
+    if (timezone2tz(tZone) == nullptr &&
         (strcmp(tzname[0], tZone) == 0 ||
          (strcmp(tZone, "UTC") != 0 && strcmp(tzname[0], "UTC") == 0)))
     {
@@ -216,7 +216,7 @@ setTimezone(const char* tZone)
             htep = tmp;
         }
         if (LtHashTab[i])
-            LtHashTab[i] = 0;
+            LtHashTab[i] = nullptr;
     }
     return true;
 }
@@ -755,7 +755,7 @@ time2user(time_t t, const QString& timeFormat, bool localtime)
 
     static char buf[128];
 
-    strftime(buf, 127, timeFormat.toLocal8Bit(), tms);
+    strftime(buf, 127, timeFormat.toLocal8Bit().constData(), tms);
     return QString::fromLocal8Bit(buf);
 }
 
@@ -815,18 +815,18 @@ date2time(const QString& date)
     char tZone[64] = "";
     std::string savedTZ;
     bool restoreTZ = false;
-    if (sscanf(date.toLocal8Bit(), "%d-%d-%d-%d:%d:%d-%s",
+    if (sscanf(date.toLocal8Bit().constData(), "%d-%d-%d-%d:%d:%d-%s",
                &y, &m, &d, &hour, &min, &sec, tZone) == 7 ||
         (sec = 0) ||    // set sec to 0
-        sscanf(date.toLocal8Bit(), "%d-%d-%d-%d:%d-%s",
+        sscanf(date.toLocal8Bit().constData(), "%d-%d-%d-%d:%d-%s",
                &y, &m, &d, &hour, &min, tZone) == 6)
     {
         const char* tz;
-        if ((tz = getenv("TZ")) != 0)
+        if ((tz = getenv("TZ")) != nullptr)
         {
             savedTZ = tz;
         }
-        if ((tz = timezone2tz(tZone)) == 0)
+        if ((tz = timezone2tz(tZone)) == nullptr)
         {
             UtilityError = QString("Illegal timezone %1").arg(tZone);
             return 0;
@@ -838,15 +838,15 @@ date2time(const QString& date)
             restoreTZ = true;
         }
     }
-    else if (sscanf(date.toLocal8Bit(), "%d-%d-%d-%d:%d:%d",
+    else if (sscanf(date.toLocal8Bit().constData(), "%d-%d-%d-%d:%d:%d",
                     &y, &m, &d, &hour, &min, &sec) == 6)
         tZone[0] = '\0';
-    else if (sscanf(date.toLocal8Bit(), "%d-%d-%d-%d:%d", &y, &m, &d, &hour, &min) == 5)
+    else if (sscanf(date.toLocal8Bit().constData(), "%d-%d-%d-%d:%d", &y, &m, &d, &hour, &min) == 5)
     {
         sec = 0;
         tZone[0] = '\0';
     }
-    else if (sscanf(date.toLocal8Bit(), "%d-%d-%d", &y, &m, &d) == 3)
+    else if (sscanf(date.toLocal8Bit().constData(), "%d-%d-%d", &y, &m, &d) == 3)
     {
         tZone[0] = '\0';
         hour = min = sec = 0;
@@ -891,7 +891,7 @@ date2time(const QString& date)
 #if defined(Q_OS_WIN) || defined(__CYGWIN__) || (defined(__SVR4) && defined(__sun))
     struct tm t = { sec, min, hour, d, m - 1, y - 1900, 0, 0, -1 };
 #else
-    struct tm t = { sec, min, hour, d, m - 1, y - 1900, 0, 0, -1, 0, 0 };
+    struct tm t = { sec, min, hour, d, m - 1, y - 1900, 0, 0, -1, 0, nullptr };
 #endif
     time_t localTime = mktime(&t);
 
@@ -912,7 +912,7 @@ date2time(const QString& date)
 QString
 formatTime(time_t t)
 {
-    return QLocale().toString(QDateTime::fromTime_t(t), QLocale::ShortFormat);
+    return QLocale().toString(QDateTime::fromSecsSinceEpoch(t), QLocale::ShortFormat);
 }
 
 QDate
@@ -929,7 +929,7 @@ qdate2time(const QDate& d)
                     0, 0, -1 };
 #else
     struct tm t = { 0, 0, 0, d.day(), d.month() - 1, d.year() - 1900,
-                    0, 0, -1, 0, 0 };
+                    0, 0, -1, 0, nullptr };
 #endif
     return mktime(&t);
 }
