@@ -1,8 +1,8 @@
 /*
  * This file is part of KPlato
  *
- * Copyright (c) 2006 Sebastian Sauer <mail@dipe.org>
- * Copyright (c) 2008 Dag Andersen <danders@get2net>
+ * SPDX-FileCopyrightText: 2006 Sebastian Sauer <mail@dipe.org>
+ * SPDX-FileCopyrightText: 2008 Dag Andersen <dag.andersen@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Library General Public License as published by
@@ -26,8 +26,8 @@
 #include "ScriptingDebug.h"
 
 #include <QStandardPaths>
-// KF5
-#include <kpluginfactory.h>
+// KF6
+#include <KPluginFactory>
 // kross
 #include <kross/core/manager.h>
 #include <kross/core/interpreter.h>
